<?php
/**
 * Catch Box Theme Options
 *
 * @package Catch Themes
 * @subpackage Catch_Box_Pro
 * @since Catch Box Pro 1.0
 */
add_action( 'admin_init', 'catchbox_register_settings' );
add_action( 'admin_menu', 'catchbox_options_menu' );


/**
 * Enqueue admin script and styles
 *
 * @uses wp_register_script, wp_enqueue_script and wp_enqueue_style
 * @Calling jquery, jquery-ui-tabs,jquery-cookie, jquery-ui-sortable, jquery-ui-draggable, media-upload, thickbox, farbtastic, colorpicker
 */
function catchbox_admin_scripts() {
	//jquery-cookie registered in functions.php
	wp_enqueue_script( 'catchbox_admin', get_template_directory_uri().'/inc/panel/admin.min.js', array( 'jquery', 'jquery-ui-tabs', 'jquery-cookie', 'jquery-ui-sortable', 'jquery-ui-draggable', 'wp-color-picker' ) );

    wp_enqueue_media();

    wp_enqueue_script( 'catchbox_upload', get_template_directory_uri().'/inc/panel/add_image_scripts.min.js', array( 'jquery') );

    wp_enqueue_style( 'catchbox_admin',get_template_directory_uri().'/inc/panel/admin.min.css', array( 'wp-color-picker' ), '1.0', 'screen' );
}
add_action( 'admin_print_styles-appearance_page_theme_options', 'catchbox_admin_scripts' );


/*
 * Create a function for Theme Options Page
 *
 * @uses add_menu_page
 * @add action admin_menu
 */
function catchbox_options_menu() {

	add_theme_page(
        __( 'Theme Options', 'catch-box' ),           // Name of page
        __( 'Theme Options', 'catch-box' ),           // Label in menu
        'edit_theme_options',                       // Capability required
        'theme_options',                                // Menu slug, used to uniquely identify the page
        'catchbox_theme_options_do_page'             // Function that renders the options page
    );

}


/*
 * Register options and validation callbacks
 *
 * @uses register_setting
 * @action admin_init
 */
function catchbox_register_settings(){
	register_setting( 'catchbox_options', 'catchbox_options', 'catchbox_theme_options_validate' );
}


/*
 * Render Catch Box Pro Theme Options page
 *
 * @uses settings_fields, get_option, bloginfo
 * @Settings Updated
 */
function catchbox_theme_options_do_page() {
	if (!isset($_REQUEST['settings-updated']))
		$_REQUEST['settings-updated'] = false;
	?>

	<div id="catchthemes" class="wrap">

    	<form method="post" action="options.php">
			<?php
                settings_fields( 'catchbox_options' );
                global $catchbox_options_settings, $catchbox_options_defaults;
                $options    = $catchbox_options_settings;
                $defaults   = $catchbox_options_defaults;


				//Getting Units
				$units = array( 'px', 'pt', 'em', '%' );
            ?>

            <?php if (false !== $_REQUEST['settings-updated']) : ?>
            	<div class="updated fade"><p><strong><?php _e('Options Saved', 'catch-box'); ?></strong></p></div>
            <?php endif; ?>

			<div id="theme-option-header">

                <div id="theme-option-title">
                    <h2 class="title"><?php _e( 'Theme Options By', 'catch-box' ); ?></h2>
                    <h2 class="logo">
                        <a href="<?php echo esc_url( __( 'http://catchthemes.com/', 'catch-box' ) ); ?>" title="<?php esc_attr_e( 'Catch Themes', 'catch-box' ); ?>" target="_blank">
                            <img src="<?php echo get_template_directory_uri().'/inc/panel/images/catch-themes.png'; ?>" alt="<?php _e( 'Catch Themes', 'catch-box' ); ?>" />
                        </a>
                    </h2>
                </div><!-- #theme-option-title -->

                <div id="theme-support">
                    <ul>
                    	<li><a class="button" href="<?php echo esc_url(__('http://catchthemes.com/support/','catch-box')); ?>" title="<?php esc_attr_e('Support', 'catch-box'); ?>" target="_blank"><?php printf(__('Support','catch-box')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('http://catchthemes.com/support-forum/forum/catch-box-pro-premium/','catch-box')); ?>" title="<?php esc_attr_e('Support Forum', 'catch-box'); ?>" target="_blank"><?php printf(__('Support Forum','catch-box')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('http://catchthemes.com/theme-instructions/catch-box-pro/','catch-box')); ?>" title="<?php esc_attr_e('Theme Instructions', 'catch-box'); ?>" target="_blank"><?php printf(__('Theme Instructions','catch-box')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('https://www.facebook.com/catchthemes/','catch-box')); ?>" title="<?php esc_attr_e('Like Catch Themes on Facebook', 'catch-box'); ?>" target="_blank"><?php printf(__('Facebook','catch-box')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('https://twitter.com/catchthemes/','catch-box')); ?>" title="<?php esc_attr_e('Follow Catch Themes on Twitter', 'catch-box'); ?>" target="_blank"><?php printf(__('Twitter','catch-box')); ?></a></li>
                        <li><a class="button" href="<?php echo esc_url(__('http://wordpress.org/support/view/theme-reviews/catch-box/','catch-box')); ?>" title="<?php esc_attr_e('Rate us 5 Star on WordPress', 'catch-box'); ?>" target="_blank"><?php printf(__('5 Star Rating','catch-box')); ?></a></li>
                   	</ul>
                </div><!-- #theme-support -->

                <div id="theme-option-header-notice">
                    <p class="notice">
                        <?php printf( _x( 'Theme Options Panel will be retired on future versions. Please use %1$s Customizer %2$s instead.','1: Customizer Link Start, 2: Customizer Link End' , 'catch-box' ) , '<a href="' . esc_url ( admin_url( 'customize.php' ) ) . '">', '</a>' ); ?>
                    </p>
                </div><!-- #theme-option-header -->

          	</div><!-- #theme-option-header -->


            <div id="catchbox_ad_tabs">
                <ul class="tabNavigation" id="mainNav">
                    <li><a href="#themeoptions"><?php _e( 'Theme Options', 'catch-box' );?></a></li>
                    <li><a href="#coloroptions"><?php _e( 'Color Options', 'catch-box' );?></a></li>
                    <li><a href="#slidersettings"><?php _e( 'Featured Slider', 'catch-box' );?></a></li>
                    <li><a href="#sociallinks"><?php _e( 'Social Links', 'catch-box' );?></a></li>
                    <li><a href="#webmaster"><?php _e( 'Webmaster Tools', 'catch-box' );?></a></li>
                </ul><!-- .tabsNavigation #mainNav -->

                <!-- Option for Theme Options -->
                <div id="themeoptions">
					<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Responsive Design', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Responsive Design?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[disable_responsive]'>
                                        <td><input type="checkbox" id="headerlogo" name="catchbox_options[disable_responsive]" value="1" <?php checked( '1', $options['disable_responsive'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>
                               	</tbody>
                          	</table>
                      		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Menu Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Enable Secondary & Footer Menu in Mobile Devices?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[enable_menus]'>
                                        <td><input type="checkbox" id="headerlogo" name="catchbox_options[enable_menus]" value="1" <?php checked( '1', $options['enable_menus'] ); ?> /> <?php _e('Check to enable', 'catch-box'); ?></td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><label><?php _e( 'Primary Mobile Menu Label', 'catch-box' ); ?></label></th>
                                        <td>
                                            <input name="catchbox_options[primary_mobile_menu_label]" type="text" value="<?php echo $options[ 'primary_mobile_menu_label' ]; ?>" size="20" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Secondary Mobile Menu label', 'catch-box' ); ?></label></th>
                                        <td>
                                            <input name="catchbox_options[secondary_mobile_menu_label]" type="text" value="<?php echo $options[ 'secondary_mobile_menu_label' ]; ?>" size="20" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Footer Mobile Menu Label', 'catch-box' ); ?></label></th>
                                        <td>
                                            <input name="catchbox_options[footer_mobile_menu_label]" type="text" value="<?php echo $options[ 'footer_mobile_menu_label' ]; ?>" size="20" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Hide Mobile Menu Labels', 'catch-box' ); ?></th>
                                            <input type='hidden' value='0' name='catchbox_options[hide_mobile_menu_labels]'>
                                            <td><input type="checkbox" id="hide_mobile_menu_labels" name="catchbox_options[hide_mobile_menu_labels]" value="1" <?php checked( '1', $options['hide_mobile_menu_labels'] ); ?> /> <?php esc_html_e('Check to hide mobile menu labels', 'catch-box'); ?></td>
                                    </tr>
                                </tbody>
                            </table>

                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>

                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Favicon Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Favicon?', 'catch-box' ); ?></th>
                                         <input type='hidden' value='0' name='catchbox_options[remove_favicon]'>
                                        <td><input type="checkbox" id="favicon" name="catchbox_options[remove_favicon]" value="1" <?php checked( '1', $options['remove_favicon'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Fav Icon URL:', 'catch-box' ); ?></th>
                                        <td><?php if ( !empty ( $options[ 'fav_icon' ] ) ) { ?>
                                                <input class="upload-url" size="65" type="text" name="catchbox_options[fav_icon]" value="<?php echo esc_url( $options [ 'fav_icon' ] ); ?>" class="upload" />
                                            <?php } else { ?>
                                                <input size="65" type="text" name="catchbox_options[fav_icon]" value="<?php echo get_template_directory_uri(); ?>/images/favicon.ico" alt="fav" />
                                            <?php }  ?>
                                            <input ref="<?php esc_attr_e( 'Insert as Fav Icon','catch-box' );?>" class="catchbox_upload_image button" type="button" value="<?php esc_attr_e( 'Add/Change Fav Icon','catch-box' );?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><?php _e( 'Preview: ', 'catch-box' ); ?></th>
                                        <td>
                                            <?php
                                                if ( !empty( $options[ 'fav_icon' ] ) ) {
                                                    echo '<img src="'.esc_url( $options[ 'fav_icon' ] ).'" alt="fav" />';
                                                } else {
                                                    echo '<img src="'. get_template_directory_uri().'/images/favicon.ico" alt="fav" />';
                                                }
                                            ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Web Clip Icon Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Web Clip Icon?', 'catch-box' ); ?></th>
                                         <input type='hidden' value='0' name='catchbox_options[remove_web_clip]'>
                                        <td><input type="checkbox" id="favicon" name="catchbox_options[remove_web_clip]" value="1" <?php checked( '1', $options['remove_web_clip'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Web Clip Icon URL:', 'catch-box' ); ?></th>
                                        <td><?php if ( !empty ( $options[ 'web_clip' ] ) ) { ?>
                                                <input class="upload-url" size="65" type="text" name="catchbox_options[web_clip]" value="<?php echo esc_url( $options [ 'web_clip' ] ); ?>" class="upload" />
                                            <?php } else { ?>
                                                <input size="65" type="text" name="catchbox_options[web_clip]" value="<?php echo get_template_directory_uri(); ?>/images/apple-touch-icon.png" alt="Web Clip Icon" />
                                            <?php }  ?>
                                            <input ref="<?php esc_attr_e( 'Insert as Web Clip Icon','catch-box' );?>" class="catchbox_upload_image button" type="button" value="<?php esc_attr_e( 'Add/Change Web Clip Icon','catch-box' );?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><?php _e( 'Preview: ', 'catch-box' ); ?></th>
                                        <td>
                                            <?php
                                                if ( !empty( $options[ 'web_clip' ] ) ) {
                                                    echo '<img src="'.esc_url( $options[ 'web_clip' ] ).'" alt="Web Clip Icon" />';
                                                } else {
                                                    echo '<img src="'. get_template_directory_uri().'/images/apple-touch-icon.png" alt="Web Clip Icon" />';
                                                }
                                            ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p><?php esc_attr_e( 'Note: Web Clip Icon for Apple devices. Recommended Size - Width 144px and Height 144px height, which will support High Resolution Devices like iPad Retina.', 'catch-box' ); ?></p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                	<tr>
                                        <th scope="row"><?php _e( 'Need to Customize Header Image?', 'catch-box' ); ?></th>
                                        <td><?php printf(__('<a class="button" href="%s">Click here</a>', 'catch-box'), admin_url('themes.php?page=custom-header')); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Move Site Title and Tagline', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[site_title_above]'>
                                        <td><input type="checkbox" id="site-title" name="catchbox_options[site_title_above]" value="1" <?php checked( '1', $options['site_title_above'] ); ?> /> <?php _e('Check to move above the Header/Logo Image', 'catch-box'); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Need to Customize Header Right Sidebar?', 'catch-box' ); ?></th>
                                        <td><?php printf(__('<a class="button" href="%s">Click here</a>', 'catch-box'), admin_url('widgets.php')); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Header Right Sidebar?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[disable_header_search]'>
                                        <td><input type="checkbox" id="headerlogo" name="catchbox_options[disable_header_search]" value="1" <?php checked( '1', $options['disable_header_search'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><label><?php _e( 'Header Top Margin', 'catch-box' ); ?></label></th>
                                        <td>
                                        	<input name="catchbox_options[header_top_size]" type="text" value="<?php echo $options[ 'header_top_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[header_top_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'header_top_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Header Right Margin', 'catch-box' ); ?></label></th>
                                        <td>
                                        	<input name="catchbox_options[header_right_size]" type="text" value="<?php echo $options[ 'header_right_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[header_right_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'header_right_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Header Bottom Margin', 'catch-box' ); ?></label></th>
                                        <td>
                                        	<input name="catchbox_options[header_bottom_size]" type="text" value="<?php echo $options[ 'header_bottom_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[header_bottom_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'header_bottom_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Header Left Margin', 'catch-box' ); ?></label></th>
                                        <td>
                                        	<input name="catchbox_options[header_left_size]" type="text" value="<?php echo $options[ 'header_left_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[header_left_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'header_left_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <?php if( $options['reset_header_space'] == '1' ) { $options['reset_header_space'] = '0'; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Header Margin?', 'catch-box' ); ?></th>
                                            <input type='hidden' value='0' name='catchbox_options[reset_header_space]'>
                                            <td><input type="checkbox" id="reset_family" name="catchbox_options[reset_header_space]" value="1" <?php checked( '1', $options['reset_header_space'] ); ?> /> <?php _e('Check to reset', 'catch-box'); ?></td>
                                    </tr>

                                </tbody>
                            </table>

                      		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>

                    	</div><!-- .option-content -->
                 	</div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Search Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                	<tr>
                                        <th scope="row"><label><?php _e( 'Default Display Text in Search', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[search_display_text]" value="<?php echo ( isset( $options[ 'search_display_text' ] ) ) ? esc_attr( $options[ 'search_display_text' ] ) : 'Search'; ?>" />
                                        </td>
                                    </tr>
                                </tbody>
                            </table>

                      		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>

                    	</div><!-- .option-content -->
                 	</div><!-- .option-container -->

					<?php
                    /**
                      * Renders the Font Family Option.
                      *
                      * @since Catch Box Pro 1.0
                      */

					  //Getting Font Available
					  $fonts = catchbox_available_fonts();

                    ?>
                    <div id="font-options" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Font Family Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>
                                	<tr>
                                        <th>
                                            <label for="catchbox_default_font_family">
                                                <?php _e( 'Default Font Family', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catchbox_options[body_font]">
												<?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options[ 'body_font' ] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_title_font_family">
                                                <?php _e( 'Site Title & Description Font Family', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catchbox_options[title_font]">
												<?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options[ 'title_font' ] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catchbox_headings_font_family">
                                                <?php _e( 'Headings Font Family', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catchbox_options[headings_font]">
												<?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options[ 'headings_font' ] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_content_font_family">
                                                <?php _e( 'Content Font Family', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <select name="catchbox_options[content_font]">
												<?php foreach( $fonts as $name => $family ) : ?>
                                                    <option value="<?php echo $name; ?>" <?php selected( $name, $options[ 'content_font' ] ); ?>><?php echo str_replace( '"', '', $family ); ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>

                                    <?php if( $options[ 'reset_typography' ] == "1" ) { $options[ 'reset_typography' ] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Fonts?', 'catch-box' ); ?></th>
                                            <input type='hidden' value='0' name='catchbox_options[reset_typography]'>
                                            <td><input type="checkbox" id="reset_family" name="catchbox_options[reset_typography]" value="1" <?php checked( '1', $options['reset_typography'] ); ?> /> <?php _e('Check to reset', 'catch-box'); ?></td>
                                    </tr>
                               	<tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<?php
                    /**
                      * Renders the Font Size Option.
                      *
                      * @since Catch Box Pro 1.0
                      */

                    ?>
                    <div id="font-options" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Font Size Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>
                                	<tr>
                                        <th>
                                            <label for="catchbox_default_font_family">
                                                <?php _e( 'Default Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[body_font_size]" type="text" value="<?php echo $options[ 'body_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[body_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'body_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_default_font_lineheight">
                                                <?php _e( 'Default Line Height', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[body_line_height]" type="text" value="<?php echo $options[ 'body_line_height' ]; ?>" size="4" />
                                            <select name="catchbox_options[body_line_height_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'body_line_height_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_site_title_font_family">
                                                <?php _e( 'Site Title Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[site_title_font_size]" type="text" value="<?php echo $options[ 'site_title_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[site_title_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'site_title_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_site_title_lineheight">
                                                <?php _e( 'Site Title Line Height', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[site_title_line_height]" type="text" value="<?php echo $options[ 'site_title_line_height' ]; ?>" size="4" />
                                            <select name="catchbox_options[site_title_line_height_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'site_title_line_height_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_site_description_font_family">
                                                <?php _e( 'Site Description Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[site_description_font_size]" type="text" value="<?php echo $options[ 'site_description_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[site_description_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'site_description_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_site_description_lineheight">
                                                <?php _e( 'Site Description Line Height', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[site_description_line_height]" type="text" value="<?php echo $options[ 'site_description_line_height' ]; ?>" size="4" />
                                            <select name="catchbox_options[site_description_line_height_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'site_description_line_height_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_title_font_family">
                                                <?php _e( 'Page/Post Title Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input name="catchbox_options[title_font_size]" type="text" value="<?php echo $options[ 'title_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[title_font_size_unit]">
                                                <?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'title_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catchbox_hone_font_family">
                                                <?php _e( 'H1 Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[h1_font_size]" type="text" value="<?php echo $options[ 'h1_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[h1_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'h1_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_htwo_font_family">
                                                <?php _e( 'H2 Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[h2_font_size]" type="text" value="<?php echo $options[ 'h2_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[h2_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'h2_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_hthree_font_family">
                                                <?php _e( 'H3 Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[h3_font_size]" type="text" value="<?php echo $options[ 'h3_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[h3_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'h3_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_hfour_font_family">
                                                <?php _e( 'H4 Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[h4_font_size]" type="text" value="<?php echo $options[ 'h4_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[h4_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'h4_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_heading_font_lineheight">
                                                <?php _e( 'Headings Line Height', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[headings_line_height]" type="text" value="<?php echo $options[ 'headings_line_height' ]; ?>" size="4" />
                                            <select name="catchbox_options[headings_line_height_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'headings_line_height_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_content_font_family">
                                                <?php _e( 'Content Font Size', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[content_font_size]" type="text" value="<?php echo $options[ 'content_font_size' ]; ?>" size="4" />
                                            <select name="catchbox_options[content_font_size_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'content_font_size_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_content_font_lineheight">
                                                <?php _e( 'Content Line Height', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<input name="catchbox_options[content_line_height]" type="text" value="<?php echo $options[ 'content_line_height' ]; ?>" size="4" />
                                            <select name="catchbox_options[content_line_height_unit]">
												<?php foreach( $units as $unit ) : ?>
                                                    <option value="<?php echo $unit; ?>" <?php selected( $unit, $options[ 'content_line_height_unit' ] ); ?>><?php echo $unit; ?></option>
                                                <?php endforeach; ?>
                                            </select>
                                        </td>

                                    </tr>

                                    <?php if( $options[ 'reset_typography_font_size' ] == "1" ) { $options[ 'reset_typography_font_size' ] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Font Size?', 'catch-box' ); ?></th>
                                            <input type='hidden' value='0' name='catchbox_options[reset_typography_font_size]'>
                                            <td><input type="checkbox" id="reset_family" name="catchbox_options[reset_typography_font_size]" value="1" <?php checked( '1', $options['reset_typography_font_size'] ); ?> /> <?php _e('Check to reset', 'catch-box'); ?></td>
                                    </tr>
                               	<tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div id="default-layout" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Default Layout', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table content-layout">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Default Layout', 'catch-box' ); ?></label></th>
                                        <td>
                                        	<label title="right-sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/right-sidebar.png" alt="Content-Sidebar" /><br />
                                            <input type="radio" name="catchbox_options[sidebar_layout]" id="right-sidebar" <?php checked($options['sidebar_layout'], 'right-sidebar') ?> value="right-sidebar"  />
                                            <?php _e( 'Right Sidebar', 'catch-box' ); ?>
                                            </label>

                                            <label title="left-Sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/left-sidebar.png" alt="Content-Sidebar" /><br />
                                            <input type="radio" name="catchbox_options[sidebar_layout]" id="left-sidebar" <?php checked($options['sidebar_layout'], 'left-sidebar') ?> value="left-sidebar"  />
                                            <?php _e( 'Left Sidebar', 'catch-box' ); ?>
                                            </label>

                                            <label title="no-sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/one-column.png" alt="Content-Sidebar" /><br />
                                            <input type="radio" name="catchbox_options[sidebar_layout]" id="no-sidebar-one-column" <?php checked($options['sidebar_layout'], 'no-sidebar-one-column') ?> value="no-sidebar-one-column"  />
                                            <?php _e( 'No Sidebar, One Column', 'catch-box' ); ?>
                                            </label>

                                            <label title="no-sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/no-sidebar-fullwidth.png" alt="Content-Sidebar" /><br />
                                            <input type="radio" name="catchbox_options[sidebar_layout]" id="no-sidebar-full-width" <?php checked($options['sidebar_layout'], 'no-sidebar-full-width') ?> value="no-sidebar-full-width"  />
                                            <?php _e( 'No Sidebar, Full Width', 'catch-box' ); ?>
                                            </label>

                                            <label title="no-sidebar" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/no-sidebar.png" alt="Content-Sidebar" /><br />
                                            <input type="radio" name="catchbox_options[sidebar_layout]" id="no-sidebar" <?php checked($options['sidebar_layout'], 'no-sidebar') ?> value="no-sidebar"  />
                                            <?php _e( 'No Sidebar', 'catch-box' ); ?>
                                            </label>
                                        </td>
                                    </tr>

                                    <?php if( $options['reset_sidebar_layout'] == '1' ) { $options['reset_sidebar_layout'] = '0'; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Default Layout?', 'catch-box' ); ?></th>
                                            <input type='hidden' value='0' name='catchbox_options[reset_sidebar_layout]'>
                                            <td><input type="checkbox" id="reset_family" name="catchbox_options[reset_sidebar_layout]" value="1" <?php checked( '1', $options['reset_sidebar_layout'] ); ?> /> <?php _e('Check to reset', 'catch-box'); ?></td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div id="default-layout" class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Homepage/Blog Content Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table content-layout">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Homepage/Blog Content Layout', 'catch-box' ); ?></label></th>
                                        <td>
                                            <label title="content-excerpt" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/excerpt.png" alt="Excerpt/Blog Display" /><br />
                                            <input type="radio" name="catchbox_options[content_layout]" id="content-excerpt" <?php checked($options['content_layout'], 'excerpt') ?> value="excerpt"  />
                                            <?php _e( 'Excerpt/Blog Display', 'catch-box' ); ?>
                                            </label>
                                            <label title="content-full" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/full-content.png" alt="Full Content Display" /><br />
                                            <input type="radio" name="catchbox_options[content_layout]" id="content-full" <?php checked($options['content_layout'], 'full') ?> value="full"  />
                                            <?php _e( 'Full Content Display', 'catch-box' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Homepage / Frontpage Category Setting', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row">
                                            <?php _e( 'Front page posts categories:', 'catch-box' ); ?>
                                            <p>
                                                <small><?php _e( 'Only posts that belong to the categories selected here will be displayed on the front page.', 'catch-box' ); ?></small>
                                            </p>
                                        </th>
                                        <td>
                                            <select name="catchbox_options[front_page_category][]" id="frontpage_posts_cats" multiple="multiple" class="select-multiple">
                                                <option value="0" <?php if ( empty( $options['front_page_category'] ) ) { echo 'selected="selected"'; } ?>><?php _e( '--Disabled--', 'catch-box' ); ?></option>
                                                <?php /* Get the list of categories */
                                                    $categories = get_categories();
                                                    if( empty( $options[ 'front_page_category' ] ) ) {
                                                        $options[ 'front_page_category' ] = array();
                                                    }
                                                    foreach ( $categories as $category) :
                                                ?>
                                                <option value="<?php echo $category->cat_ID; ?>" <?php if ( in_array( $category->cat_ID, $options['front_page_category'] ) ) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                                <?php endforeach; ?>
                                            </select><br />
                                            <span class="description"><?php _e( 'You may select multiple categories by holding down the CTRL key.', 'catch-box' ); ?></span>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Excerpt / More Tag Settings', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Make More Text Tag accessible?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[more_tag_accessible]'>
                                        <td><input type="checkbox" id="more_tag_accessible" name="catchbox_options[more_tag_accessible]" value="1" <?php checked( '1', $options['more_tag_accessible'] ); ?> /> <?php _e('Check to enable', 'catch-box'); ?></td>
                                    </tr>
									<tr class="excerpt-inaccessible">
                                        <th scope="row"><label><?php _e( 'More Text Tag', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[more_tag_text]" value="<?php echo ( isset( $options[ 'more_tag_text' ] ) ) ? esc_attr( $options[ 'more_tag_text' ] ) : 'Continue Reading &rarr;'; ?>" />
                                        </td>
                                    </tr>
                                    <tr class="excerpt-accessible">
                                        <th scope="row"><label><?php _e( 'More Text Tag', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[more_tag_text_accessible]" value="<?php echo ( isset( $options[ 'more_tag_text_accessible' ] ) ) ? esc_attr( $options[ 'more_tag_text_accessible' ] ) : 'Continue Reading'; ?>" />
                                        </td>
                                    </tr>
                                    <tr class="excerpt-accessible">
                                        <th scope="row"><label><?php _e( 'More Text Icon', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[more_tag_icon_accessible]" value="<?php echo ( isset( $options[ 'more_tag_icon_accessible' ] ) ) ? esc_attr( $options[ 'more_tag_icon_accessible' ] ) : '&rarr;'; ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e( 'Excerpt length(words)', 'catch-box' ); ?></th>
                                        <td><input type="text" size="3" name="catchbox_options[excerpt_length]" value="<?php echo intval( $options[ 'excerpt_length' ] ); ?>" /></td>
                                    </tr>
                              	</tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Feed Redirect', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
									<tr>
                                        <th scope="row"><label><?php _e( 'Feed Redirect URL', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="70" name="catchbox_options[feed_url]" value="<?php echo esc_attr( $options[ 'feed_url' ] ); ?>" /> <?php _e( 'Add in the Feedburner URL', 'catch-box' ); ?>
                                        </td>
                                    </tr>
                               	</tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Comments Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table comment-settings">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Commenting', 'catch-box' ); ?></th>
                                        <td>
                                        	<label title="commenting-setting" class="box"><input type="radio" name="catchbox_options[commenting_setting]" id="default" <?php checked($options['commenting_setting'], 'default'); ?> value="default"  />
                                            <?php _e( 'Use WordPress Settings', 'catch-box' ); ?>
                                            </label>

                                        	<label title="commenting-setting" class="box"><input type="radio" name="catchbox_options[commenting_setting]" id="page" <?php checked($options['commenting_setting'], 'page'); ?> value="page"  />
                                            <?php _e( 'Disabled for Pages', 'catch-box' ); ?>
                                            </label>

                                        	<label title="commenting-setting" class="box"><input type="radio" name="catchbox_options[commenting_setting]" id="disable" <?php checked($options['commenting_setting'], 'disable'); ?> value="disable"  />
                                            <?php _e( 'Disabled Completely', 'catch-box' ); ?>
                                            </label>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Website Field?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[commenting_disable_url]'>
                                        <td><input type="checkbox" id="headerlogo" name="catchbox_options[commenting_disable_url]" value="1" <?php checked( '1', $options['commenting_disable_url'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>

                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<div class="option-container">
						<h3 class="option-toggle"><a href="#"><?php _e( 'Footer Editor Option', 'catch-box' ); ?></a></h3>
						<div class="option-content inside">
							<table class="form-table">
								<tr>
									<th scope="row">
										<label for="footer-editor"><?php _e( 'Footer Editor', 'catch-box' ); ?></label>
                                         <p>
											<small><?php _e( 'You can add custom <acronym title="Hypertext Markup Language">HTML</acronym> and/or shortcodes, which will be automatically inserted into your theme.<br />Some shorcodes: [the-year], [site-link], [wp-link] for current year, your site link, wordpress site link respectively.', 'catch-box' ); ?></small>
										</p>
									</th>
									<td>
										<?php
										$settings = array(
                                            	'wpautop'				=> false,
												'media_buttons'			=> false,  // Don't show upload botton
												'textarea_name'			=> 'catchbox_options[footer_code]',
                                            	'tinymce' 				=> false,  // Don't use TinyMCE in a meta box.
                                             	'textarea_rows'			=> 3
                                        	);
                                 		wp_editor( esc_textarea( $options[ 'footer_code' ] ), 'catchbox_options_footer_code', $settings ); ?>
									</td>
								</tr>
                                <?php if( $options[ 'reset_footer' ] == "1" ) { $options[ 'reset_footer' ] = "0"; } ?>
                                <tr>
                                    <th scope="row"><?php _e( 'Reset Footer?', 'catch-box' ); ?></th>
                                    <input type='hidden' value='0' name='catchbox_options[reset_footer]'>
                                    <td>
                                        <input type="checkbox" id="headerlogo" name="catchbox_options[reset_footer]" value="1" <?php checked( '1', $options['reset_footer'] ); ?> /> <?php _e('Check to reset', 'catch-box'); ?>
                                    </td>
                                </tr>
							</table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
						</div><!-- .option-content -->
          			</div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Custom CSS', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Enter your custom CSS styles.', 'catch-box' ); ?></th>
                                        <td>
                                            <textarea name="catchbox_options[custom_css]" id="custom-css" cols="90" rows="12"><?php echo esc_attr( $options[ 'custom_css' ] ); ?></textarea>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><?php _e( 'CSS Tutorial from W3Schools.', 'catch-box' ); ?></th>
                                        <td>
                                            <a class="button" href="<?php echo esc_url( __( 'http://www.w3schools.com/css/default.asp','catch-box' ) ); ?>" title="<?php esc_attr_e( 'CSS Tutorial', 'catch-box' ); ?>" target="_blank"><?php _e( 'Click Here to Read', 'catch-box' );?></a>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Scroll Up', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Scroll Up?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[disable_scrollup]'>
                                        <td><input type="checkbox" id="headerlogo" name="catchbox_options[disable_scrollup]" value="1" <?php checked( '1', $options['disable_scrollup'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>
                               	</tbody>
                          	</table>
                      		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

					<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Update Notifier', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Disable Update Notifier?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[disable_notifier]'>
                                        <td><input type="checkbox" id="headerlogo" name="catchbox_options[disable_notifier]" value="1" <?php checked( '1', $options['disable_notifier'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                    </tr>
                               	</tbody>
                          	</table>
                      		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                </div> <!-- #designsettings -->

                <div id="coloroptions">
                	<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Color Scheme', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Default Color Scheme', 'catch-box' ); ?></label></th>
                                        <td>
                                            <label title="color-light" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/light.png" alt="color-light" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-light" <?php checked($options['color_scheme'], 'light') ?> value="light"  />
                                            <?php _e( 'Light', 'catch-box' ); ?>
                                            </label>
                                            <label title="color-dark" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/dark.png" alt="color-dark" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-dark" <?php checked($options['color_scheme'], 'dark') ?> value="dark"  />
                                            <?php _e( 'Dark', 'catch-box' ); ?>
                                            </label>
                                            <label title="color-blue" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/blue.png" alt="color-blue" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-blue" <?php checked($options['color_scheme'], 'blue') ?> value="blue"  />
                                            <?php _e( 'Blue', 'catch-box' ); ?>
                                            </label>
                                            <label title="color-green" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/green.png" alt="color-green" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-green" <?php checked($options['color_scheme'], 'green') ?> value="green"  />
                                            <?php _e( 'Green', 'catch-box' ); ?>
                                            </label>
                                            <label title="color-red" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/red.png" alt="color-red" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-red" <?php checked($options['color_scheme'], 'red') ?> value="red"  />
                                            <?php _e( 'Red', 'catch-box' ); ?>
                                            </label>
                                            <label title="color-brown" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/brown.png" alt="color-brown" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-brown" <?php checked($options['color_scheme'], 'brown') ?> value="brown"  />
                                            <?php _e( 'Brown', 'catch-box' ); ?>
                                            </label>
                                            <label title="color-orange" class="box"><img src="<?php echo get_template_directory_uri(); ?>/images/orange.png" alt="color-orange" /><br />
                                            <input type="radio" name="catchbox_options[color_scheme]" id="color-orange" <?php checked($options['color_scheme'], 'orange') ?> value="orange"  />
                                            <?php _e( 'Orange', 'catch-box' ); ?>
                                            </label>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>

                     		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                    	</div><!-- .option-content -->
                 	</div><!-- .option-container -->

                	<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Custom Colors', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                        	<table class="form-table">
                                <tbody>

                                	<tr>
                                        <th>
                                            <label for="catchbox_background_color">
                                                <?php _e( 'Main Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<a class="button" href="<?php echo admin_url('themes.php?page=custom-background'); ?>">
                                            	<?php _e( 'Click Here to change Main Background Image/Color', 'catch-box' ); ?>
                                           	</a>
                                        </td>
                                    </tr>
                                	<tr>
                                        <th>
                                            <label for="catchbox_header_background">
                                                <?php _e( 'Header Background:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[header_background]" size="8" value="<?php echo ( isset( $options[ 'header_background' ] ) ) ? esc_attr( $options[ 'header_background' ] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'header_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                	<tr>
                                        <th>
                                            <label for="catchbox_slider_background">
                                                <?php _e( 'Slider Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[slider_background]" size="8" value="<?php echo ( isset( $options[ 'slider_background' ] ) ) ? esc_attr( $options[ 'slider_background' ] ) : '#555'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'slider_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                	<tr>
                                        <th>
                                            <label for="catchbox_content_background">
                                                <?php _e( 'Content Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[content_background]" size="8" value="<?php echo ( isset( $options[ 'content_background' ] ) ) ? esc_attr( $options[ 'content_background' ] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'content_background' ] ); ?>" />
                                        </td>
                                    </tr>

                                	<tr>
                                        <th>
                                            <label for="catchbox_article_background">
                                                <?php _e( 'Article Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[article_background]" size="8" value="<?php echo ( isset( $options[ 'article_background' ] ) ) ? esc_attr( $options[ 'article_background' ] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'article_background' ] ); ?>" />
                                        </td>
                                    </tr>

                                    <tr>
                                        <th>
                                            <label for="catchbox_footer_background">
                                                <?php _e( ' Footer Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[footer_background]" size="8" value="<?php echo ( isset( $options[ 'footer_background' ] ) ) ? esc_attr( $options[ 'footer_background' ] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'footer_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                	<tr>
                                        <th>
                                            <label for="catchbox_content_background">
                                                <?php _e( ' Footer Sidebar Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[footer_sidebar_background]" size="8" value="<?php echo ( isset( $options[ 'footer_sidebar_background' ] ) ) ? esc_attr( $options[ 'footer_sidebar_background' ] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'footer_sidebar_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                 	<tr>
                                        <th>
                                            <label for="catchbox_widget_background">
                                                <?php _e( 'Widget Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[widget_background]" size="8" value="<?php echo ( isset( $options[ 'widget_background' ] ) ) ? esc_attr( $options[ 'widget_background' ] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'widget_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_header_color">
                                                <?php _e( 'Site Title & Description Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                        	<a class="button" href="<?php echo admin_url('themes.php?page=custom-header'); ?>">
                                            	<?php _e( 'Click Here to change Site Title and Tagline Text Color', 'catch-box' ); ?>
                                           	</a>
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_title_hover_color">
                                                <?php _e( 'Site Title Hover Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[title_hover_color]" size="8" value="<?php echo ( isset( $options[ 'title_hover_color' ] ) ) ? esc_attr( $options[ 'title_hover_color' ] ) : '#1982d1'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'title_hover_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                	<tr>
                                        <th>
                                            <label for="catchbox_heading_color">
                                                <?php _e( 'Title Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[heading_color]" size="8" value="<?php echo ( isset( $options[ 'heading_color' ] ) ) ? esc_attr( $options[ 'heading_color' ] ) : '#222'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'heading_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_heading_hover_color">
                                                <?php _e( 'Title Hover Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[heading_hover_color]" size="8" value="<?php echo ( isset( $options[ 'heading_hover_color' ] ) ) ? esc_attr( $options[ 'heading_hover_color' ] ) : '#1982d1'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'heading_hover_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_slider_text">
                                                <?php _e( 'Slider Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[slider_text]" size="8" value="<?php echo ( isset( $options[ 'slider_text' ] ) ) ? esc_attr( $options[ 'slider_text' ] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'slider_text' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_meta_color">
                                                <?php _e( 'Meta Description Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[meta_color]" size="8" value="<?php echo ( isset( $options[ 'meta_color' ] ) ) ? esc_attr( $options[ 'meta_color' ] ) : '#666'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'meta_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_text_color">
                                                <?php _e( 'Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[text_color]" size="8" value="<?php echo ( isset( $options[ 'text_color' ] ) ) ? esc_attr( $options[ 'text_color' ] ) : '#373737'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_link_color">
                                                <?php _e( 'Link Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[link_color]" size="8" value="<?php echo ( isset( $options[ 'link_color' ] ) ) ? esc_attr( $options[ 'link_color' ] ) : '#337ab7'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'link_color' ] ); ?>" />
                                        </td>
                                    </tr>
        							<tr>
                                        <th>
                                            <label for="catchbox_widget_heading_color">
                                                <?php _e( 'Sidebar Widget Title Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[widget_heading_color]" size="8" value="<?php echo ( isset( $options[ 'widget_heading_color' ] ) ) ? esc_attr( $options[ 'widget_heading_color' ] ) : '#222'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'widget_heading_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_widget_text_color">
                                                <?php _e( 'Sidebar Widget Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[widget_text_color]" size="8" value="<?php echo ( isset( $options[ 'widget_text_color' ] ) ) ? esc_attr( $options[ 'widget_text_color' ] ) : '#373737'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'widget_text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                   	<tr>
                                        <th>
                                            <label for="catchbox_menu_background">
                                                <?php _e( 'Menu Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[menu_background]" size="8" value="<?php echo ( isset( $options[ 'menu_background' ] ) ) ? esc_attr( $options[ 'menu_background' ] ) : '#3d3d3d'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'menu_background' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_menu_color">
                                                <?php _e( 'Menu Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[menu_color]" size="8" value="<?php echo ( isset( $options[ 'menu_color' ] ) ) ? esc_attr( $options[ 'menu_color' ] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'menu_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_hover_background_color">
                                                <?php _e( 'Menu Hover Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[hover_background_color]" size="8" value="<?php echo ( isset( $options[ 'hover_background_color' ] ) ) ? esc_attr( $options[ 'hover_background_color' ] ) : '#e5e5e5'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'hover_background_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_hover_text_color">
                                                <?php _e( 'Menu Hover Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[hover_text_color]" size="8" value="<?php echo ( isset( $options[ 'hover_text_color' ] ) ) ? esc_attr( $options[ 'hover_text_color' ] ) : '#373737'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'hover_text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_active_background_color">
                                                <?php _e( 'Menu Active Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[active_background_color]" size="8" value="<?php echo ( isset( $options[ 'active_background_color' ] ) ) ? esc_attr( $options[ 'active_background_color' ] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'active_background_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_active_text_color">
                                                <?php _e( 'Menu Active Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[active_text_color]" size="8" value="<?php echo ( isset( $options[ 'active_text_color' ] ) ) ? esc_attr( $options[ 'active_text_color' ] ) : '#eee'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'active_text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_sub_menu_bg_color">
                                                <?php _e( 'Sub-Menu Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[sub_menu_bg_color]" size="8" value="<?php echo ( isset( $options[ 'sub_menu_bg_color' ] ) ) ? esc_attr( $options[ 'sub_menu_bg_color' ] ) : '#f9f9f9'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'sub_menu_bg_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_sub_menu_text_color">
                                                <?php _e( 'Sub-Menu Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[sub_menu_text_color]" size="8" value="<?php echo ( isset( $options[ 'sub_menu_text_color' ] ) ) ? esc_attr( $options[ 'sub_menu_text_color' ] ) : '#444'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'sub_menu_text_color' ] ); ?>"  />
                                        </td>
                                    </tr>
                                   	<tr>
                                        <th>
                                            <label for="catchbox_menu_background">
                                                <?php _e( 'Scroll Up Background Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[scrollup_bg_color]" size="8" value="<?php echo ( isset( $options[ 'scrollup_bg_color' ] ) ) ? esc_attr( $options[ 'scrollup_bg_color' ] ) : '#000'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'scrollup_bg_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <tr>
                                        <th>
                                            <label for="catchbox_scrollup_text_color">
                                                <?php _e( 'Scroll Up Text Color:', 'catch-box' ); ?>
                                            </label>
                                        </th>
                                        <td>
                                            <input type="text" class="catchbox_color_picker" name="catchbox_options[scrollup_text_color]" size="8" value="<?php echo ( isset( $options[ 'scrollup_text_color' ] ) ) ? esc_attr( $options[ 'scrollup_text_color' ] ) : '#fff'; ?>" data-default-color="<?php echo esc_attr( $defaults[ 'scrollup_text_color' ] ); ?>" />
                                        </td>
                                    </tr>
                                    <?php if( $options[ 'reset_color' ] == "1" ) { $options[ 'reset_color' ] = "0"; } ?>
                                    <tr>
                                        <th scope="row"><?php _e( 'Reset Color?', 'catch-box' ); ?></th>
                                        <input type='hidden' value='0' name='catchbox_options[reset_color]'>
                                        <td>
                                        	<input type="checkbox" id="headerlogo" name="catchbox_options[reset_color]" value="1" <?php checked( '1', $options['reset_color'] ); ?> /> <?php _e('Check to reset', 'catch-box'); ?>
                                       	</td>
                                    </tr>
                                </tbody>
                            </table>

                     		<p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                    	</div><!-- .option-content -->
                 	</div><!-- .option-container -->

                </div><!-- #coloroptions -->


                <div id="slidersettings">
                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Slider Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tr>
                                    <th scope="row"><label><?php _e( 'Select Slider Type', 'catch-box' ); ?></label></th>
                                    <td>
                                        <label title="post-slider" class="box">
                                        <input type="radio" name="catchbox_options[select_slider_type]" id="post-slider" <?php checked($options['select_slider_type'], 'post-slider') ?> value="post-slider"  />
                                        <?php _e( 'Featured Post Slider', 'catch-box' ); ?>
                                        </label>

                                        <label title="page-slider" class="box">
                                        <input type="radio" name="catchbox_options[select_slider_type]" id="page-slider" <?php checked($options['select_slider_type'], 'page-slider') ?> value="page-slider"  />
                                        <?php _e( 'Featured Page Slider', 'catch-box' ); ?>
                                        </label>

                                        <label title="page-category" class="box">
                                        <input type="radio" name="catchbox_options[select_slider_type]" id="category-slider" <?php checked($options['select_slider_type'], 'category-slider') ?> value="category-slider"  />
                                        <?php _e( 'Featured Category Slider', 'catch-box' ); ?>
                                        </label>

       									<label title="image-slider" class="box">
                                        <input type="radio" name="catchbox_options[select_slider_type]" id="image-slider" <?php checked($options['select_slider_type'], 'image-slider') ?> value="image-slider"  />
                                        <?php _e( 'Featured Image Slider', 'catch-box' ); ?>
                                        </label>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label><?php _e( 'Slider Layout', 'catch-box' ); ?></label></th>
                                    <td>
                                        <label title="slider-normal" class="box">
                                        <input type="radio" name="catchbox_options[select_slider_layout]" id="normal" <?php checked($options['select_slider_layout'], 'normal') ?> value="normal"  />
                                        <?php _e( 'Normal Width Slider', 'catch-box' ); ?>
                                        </label>

                                        <label title="slider-full-width" class="box">
                                        <input type="radio" name="catchbox_options[select_slider_layout]" id="fullwidth" <?php checked($options['select_slider_layout'], 'fullwidth') ?> value="fullwidth"  />
                                        <?php _e( 'Full Width Slider', 'catch-box' ); ?>
                                        </label>


                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><label><?php _e( 'Enable Sidebar', 'catch-box' ); ?></label></th>
                                    <td>
                                        <label title="enable-slider-homepager" class="box">
                                        <input type="radio" name="catchbox_options[enable_slider]" id="enable-slider-homepage" <?php checked($options['enable_slider'], 'enable-slider-homepage') ?> value="enable-slider-homepage"  />
                                        <?php _e( 'Homepage / Frontpage', 'catch-box' ); ?>
                                        </label>
                                        <label title="enable-slider-allpage" class="box">
                                        <input type="radio" name="catchbox_options[enable_slider]" id="enable-slider-allpage" <?php checked($options['enable_slider'], 'enable-slider-allpage') ?> value="enable-slider-allpage"  />
                                         <?php _e( 'Entire Site', 'catch-box' ); ?>
                                        </label>
                                        <label title="disable-slider" class="box">
                                        <input type="radio" name="catchbox_options[enable_slider]" id="disable-slider" <?php checked($options['enable_slider'], 'disable-slider') ?> value="disable-slider"  />
                                         <?php _e( 'Disable', 'catch-box' ); ?>
                                        </label>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Number of Slides', 'catch-box' ); ?></th>
                                    <td><input type="text" name="catchbox_options[slider_qty]" value="<?php echo intval( $options[ 'slider_qty' ] ); ?>" size="2" /></td>
                                </tr>

                                <tr>
                                    <th>
                                        <label for="catchbox_cycle_style"><?php _e( 'Transition Effect:', 'catch-box' ); ?></label>
                                    </th>
                                    <td>
                                        <select id="catchbox_cycle_style" name="catchbox_options[transition_effect]">
                                            <option value="fade" <?php selected('fade', $options['transition_effect']); ?>><?php _e( 'fade', 'catch-box' ); ?></option>
                                            <option value="wipe" <?php selected('wipe', $options['transition_effect']); ?>><?php _e( 'wipe', 'catch-box' ); ?></option>
                                            <option value="scrollUp" <?php selected('scrollUp', $options['transition_effect']); ?>><?php _e( 'scrollUp', 'catch-box' ); ?></option>
                                            <option value="scrollDown" <?php selected('scrollDown', $options['transition_effect']); ?>><?php _e( 'scrollDown', 'catch-box' ); ?></option>
                                            <option value="scrollLeft" <?php selected('scrollLeft', $options['transition_effect']); ?>><?php _e( 'scrollLeft', 'catch-box' ); ?></option>
                                            <option value="scrollRight" <?php selected('scrollRight', $options['transition_effect']); ?>><?php _e( 'scrollRight', 'catch-box' ); ?></option>
                                            <option value="blindX" <?php selected('blindX', $options['transition_effect']); ?>><?php _e( 'blindX', 'catch-box' ); ?></option>
                                            <option value="blindY" <?php selected('blindY', $options['transition_effect']); ?>><?php _e( 'blindY', 'catch-box' ); ?></option>
                                            <option value="blindZ" <?php selected('blindZ', $options['transition_effect']); ?>><?php _e( 'blindZ', 'catch-box' ); ?></option>
                                            <option value="cover" <?php selected('cover', $options['transition_effect']); ?>><?php _e( 'cover', 'catch-box' ); ?></option>
                                            <option value="shuffle" <?php selected('shuffle', $options['transition_effect']); ?>><?php _e( 'shuffle', 'catch-box' ); ?></option>
                                        </select>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Transition Delay', 'catch-box' ); ?></th>
                                    <td>
                                        <input type="text" name="catchbox_options[transition_delay]" value="<?php echo $options[ 'transition_delay' ]; ?>" size="2" />
                                       <span class="description"><?php _e( 'second(s)', 'catch-box' ); ?></span>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Transition Length', 'catch-box' ); ?></th>
                                    <td>
                                        <input type="text" name="catchbox_options[transition_duration]" value="<?php echo $options[ 'transition_duration' ]; ?>" size="2" />
                                        <span class="description"><?php _e( 'second(s)', 'catch-box' ); ?></span>
                                    </td>
                                </tr>

                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container image-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Image Slider Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <div id="featured-image-slider">
                            	<div class="row">
                                    <div class="col col1">
                                        <?php _e( 'Image Slider Tutorial', 'catch-box' ); ?>
                                    </div>
                                    <div class="col col2">
                                    	<a class="button" href="<?php echo esc_url( __( 'http://catchthemes.com/blog/videos-blog/video-series-adding-featured-image-slider/','catch-box' ) ); ?>" title="<?php esc_attr_e( 'Image Slider Tutorial', 'catch-box' ); ?>" target="_blank"><?php _e( 'Click Here to Read Image Slider Tutorial', 'catch-box' );?></a>
                                    </div>
                               	</div><!-- .row -->
                                <?php for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ): ?>
                                    <div class="slides slides-<?php echo $i; ?>">
                                        <h3><?php _e( 'Featued Slider', 'catch-box' ); ?> #<?php echo $i; ?></h3>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Image', 'catch-box' ); ?>
                                            </div>
                                            <div class="col col2">
                                                <input size="90" type="text" class="upload-url" name="catchbox_options[featured_image_slider_image][<?php echo $i; ?>]" value="<?php if( array_key_exists( 'featured_image_slider_image', $options ) && array_key_exists( $i, $options[ 'featured_image_slider_image' ] ) ) echo esc_url( $options[ 'featured_image_slider_image' ][ $i ] ); ?>" />
                                                <input ref="<?php esc_attr_e( 'Insert','catch-box' );?>" class="catchbox_upload_image button" type="button" value="<?php esc_attr_e( 'Add/Change','catch-box' );?>" />
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Link', 'catch-box' ); ?>
                                            </div>
                                            <div class="col col2">
                                                <input size="90" type="text" name="catchbox_options[featured_image_slider_link][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'featured_image_slider_link', $options ) && array_key_exists( $i, $options[ 'featured_image_slider_link' ] ) ) echo esc_url( $options[ 'featured_image_slider_link' ][ $i ] ); ?>" />
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Target: Open Link in New Window', 'catch-box' ); ?>
                                                <input type='hidden' value='0' name='catchbox_options[featured_image_slider_base][<?php echo absint( $i ); ?>]'>
                                            </div>
                                            <div class="col col2">
                                                <input type="checkbox" name="catchbox_options[featured_image_slider_base][<?php echo absint( $i ); ?>]" value="1" <?php if( array_key_exists( 'featured_image_slider_base', $options ) && array_key_exists( $i, $options[ 'featured_image_slider_base' ] ) ) checked( '1', $options[ 'featured_image_slider_base' ][ $i ] ); ?> /> <?php _e( 'Check to open in new window', 'catch-box' ); ?>
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Title', 'catch-box' ); ?>
                                            </div>
                                            <div class="col col2">
                                                <input size="90" type="text" name="catchbox_options[featured_image_slider_title][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'featured_image_slider_title', $options ) && array_key_exists( $i, $options[ 'featured_image_slider_title' ] ) ) echo esc_attr( $options[ 'featured_image_slider_title' ][ $i ] ); ?>" />
                                            </div>
                                        </div>
                                        <div class="row">
                                            <div class="col col1">
                                                <?php _e( 'Content', 'catch-box' ); ?>
                                            </div>
                                            <div class="col col2">
                                                <textarea name="catchbox_options[featured_image_slider_content][<?php echo absint( $i ); ?>]" cols="100" rows="3"><?php if( array_key_exists( 'featured_image_slider_content', $options ) && array_key_exists( $i, $options[ 'featured_image_slider_content' ] ) ) echo esc_html( $options[ 'featured_image_slider_content' ][ $i ] ); ?></textarea>
                                            </div>
                                        </div>
                                        <div class="clear"></div>
                                    </div> <!-- .slides -->
                                <?php endfor; ?>
                            </div> <!-- .featured-image-slider -->
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container post-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Post Slider Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tr>
                                    <th scope="row"><?php _e( 'Post Slider Tutorial', 'catch-box' ); ?></th>
                                    <td>
                                        <a class="button" href="<?php echo esc_url( __( 'http://catchthemes.com/blog/videos-blog/video-series-adding-featured-post-slider/','catch-box' ) ); ?>" title="<?php esc_attr_e( 'Post Slider Tutorial', 'catch-box' ); ?>" target="_blank"><?php _e( 'Click Here to Read Post Slider Tutorial', 'catch-box' );?></a>
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Exclude Slider post from Homepage posts?', 'catch-box' ); ?></th>
                                     <input type='hidden' value='0' name='catchbox_options[exclude_slider_post]'>
                                    <td><input type="checkbox" id="headerlogo" name="catchbox_options[exclude_slider_post]" value="1" <?php checked( '1', $options['exclude_slider_post'] ); ?> /> <?php _e('Check to exclude', 'catch-box'); ?></td>
                                </tr>
                                <tbody class="sortable">
                                    <?php for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ): ?>
                                    <tr>
                                        <th scope="row"><label class="handle"><?php _e( 'Featured Slider Post #', 'catch-box' ); ?><span class="count"><?php echo absint( $i ); ?></span></label></th>
                                        <td><input type="text" name="catchbox_options[featured_slider][<?php echo absint( $i ); ?>]" value="<?php if( array_key_exists( 'featured_slider', $options ) && array_key_exists( $i, $options[ 'featured_slider' ] ) ) echo absint( $options[ 'featured_slider' ][ $i ] ); ?>" />
                                        <a href="<?php bloginfo ( 'url' );?>/wp-admin/post.php?post=<?php if( array_key_exists ( 'featured_slider', $options ) && array_key_exists ( $i, $options[ 'featured_slider' ] ) ) echo absint( $options[ 'featured_slider' ][ $i ] ); ?>&action=edit" class="button" title="<?php esc_attr_e( 'Click Here To Edit', 'catch-box' ); ?>" target="_blank"><?php _e( 'Click Here To Edit', 'catch-box' ); ?></a>
                                        </td>
                                    </tr>
                                    <?php endfor; ?>
                                </tbody>
                            </table>
                            <p><?php _e( 'Note: Here You can put your Post IDs which displays on Homepage as slider.', 'catch-box' ); ?> </p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container page-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Page Slider Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody class="sortable">
                                    <?php for ( $i = 1; $i <= $options[ 'slider_qty' ]; $i++ ): ?>
                                    <tr>
                                        <th scope="row"><label class="handle"><?php _e( 'Featured Slider Page #', 'catch-box' ); ?><span class="count"><?php echo absint( $i ); ?></span></label></th>
                                        <td>
<?php
                                            $catchbox_name = 'catchbox_options[featured_slider_page][' . absint( $i ) . ']';
                                            $catchbox_args = array(
                                                            'depth'             => 0,
                                                            'child_of'          => 0,
                                                            'selected'          => ( isset( $options[ 'featured_slider_page' ][ $i ] ) && $options[ 'featured_slider_page' ][ $i ] > 0 ) ? $options[ 'featured_slider_page' ][ $i ] : '',
                                                            'echo'              => 1,
                                                            'name'              => $catchbox_name,
                                                            'id'                => $catchbox_name,
                                                            'show_option_none' => '--Select One--',
                                                        );
                                           wp_dropdown_pages( $catchbox_args );
                                        ?>

                                        <?php if( isset( $options[ 'featured_slider_page' ][ $i ] ) && $options[ 'featured_slider_page' ][ $i ] > 0 ) : ?>
                                            <a href="<?php bloginfo ( 'url' );?>/wp-admin/post.php?post=<?php if( array_key_exists ( 'featured_slider_page', $options ) && array_key_exists ( $i, $options[ 'featured_slider_page' ] ) ) echo absint( $options[ 'featured_slider_page' ][ $i ] ); ?>&action=edit" class="button" title="<?php esc_attr_e( 'Click Here To Edit', 'catch-box' ); ?>" target="_blank"><?php _e( 'Click Here To Edit', 'catch-box' ); ?></a>
                                        <?php endif; ?>
                                        </td>
                                    </tr>
                                    <?php endfor; ?>
                                </tbody>
                            </table>
                            <p><?php _e( 'Note: Here You can put your Page IDs which displays on Homepage as slider.', 'catch-box' ); ?> </p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container category-slider">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Featured Category Slider Options', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row">
                                            <label for="layouts"><?php _e( 'Select Slider Categories', 'catch-box' ); ?></label>
                                            <p><small><?php _e( 'Use this only if you want to display posts from Specific Categories in Featured Slider', 'catch-box' ); ?></small></p>
                                        </th>
                                        <td>
                                            <select name="catchbox_options[slider_category][]" id="frontpage_posts_cats" multiple="multiple" class="select-multiple">
                                                <option value="0" <?php if ( empty( $options['slider_category'] ) ) { selected( true, true ); } ?>><?php _e( '--Disabled--', 'catch-box' ); ?></option>
                                                <?php /* Get the list of categories */
                                                    if( empty( $options[ 'slider_category' ] ) ) {
                                                        $options[ 'slider_category' ] = array();
                                                    }
                                                    $categories = get_categories();
                                                    foreach ( $categories as $category) :
                                                ?>
                                                <option value="<?php echo $category->cat_ID; ?>" <?php if ( in_array( $category->cat_ID, $options['slider_category'] ) ) {echo 'selected="selected"';}?>><?php echo $category->cat_name; ?></option>
                                                <?php endforeach; ?>
                                            </select><br />
                                            <span class="description"><?php _e( 'You may select multiple categories by holding down the CTRL key.', 'catch-box' ); ?></span>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p><?php _e( 'Note: Here you can select the categories from which latest posts will display on Featured Slider.', 'catch-box' ); ?> </p>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save Changes', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                	</div><!-- .option-container -->

                </div><!-- #slidersettings -->

                <div id="sociallinks">
                	<div class="option-container">
                        <table class="form-table">
                            <tbody>
                                <tr>
                                    <th scope="row"><?php _e( 'Disable Social Links in Footer?', 'catch-box' ); ?></th>
                                    <input type='hidden' value='0' name='catchbox_options[disable_footer_social]'>
                                    <td><input type="checkbox" id="headerlogo" name="catchbox_options[disable_footer_social]" value="1" <?php checked( '1', $options['disable_footer_social'] ); ?> /> <?php _e('Check to disable', 'catch-box'); ?></td>
                                </tr>

                                <tr>
                                    <th scope="row"><h4><?php _e( 'Facebook', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_facebook]" value="<?php echo esc_url( $options[ 'social_facebook' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Twitter', 'catch-box' ); ?> </h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_twitter]" value="<?php echo esc_url( $options[ 'social_twitter'] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Google+', 'catch-box' ); ?> </h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_googleplus]" value="<?php echo esc_url( $options[ 'social_googleplus'] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Pinterest', 'catch-box' ); ?> </h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_pinterest]" value="<?php echo esc_url( $options[ 'social_pinterest'] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Youtube', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_youtube]" value="<?php echo esc_url( $options[ 'social_youtube' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Vimeo', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_vimeo]" value="<?php echo esc_url( $options[ 'social_vimeo' ] ); ?>" />
                                    </td>
                                </tr>

                                <tr>
                                    <th scope="row"><h4><?php _e( 'Linkedin', 'catch-box' ); ?> </h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_linkedin]" value="<?php echo esc_url( $options[ 'social_linkedin'] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'AIM', 'catch-box' ); ?> </h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_aim]" value="<?php echo esc_url( $options[ 'social_aim'] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'MySpace', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_myspace]" value="<?php echo esc_url( $options[ 'social_myspace' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Flickr', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_flickr]" value="<?php echo esc_url( $options[ 'social_flickr' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Tumblr', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_tumblr]" value="<?php echo esc_url( $options[ 'social_tumblr' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'deviantART', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_deviantart]" value="<?php echo esc_url( $options[ 'social_deviantart' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Dribbble', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_dribbble]" value="<?php echo esc_url( $options[ 'social_dribbble' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'WordPress', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_wordpress]" value="<?php echo esc_url( $options[ 'social_wordpress' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'RSS', 'catch-box' ); ?> </h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_rss]" value="<?php echo esc_url( $options[ 'social_rss' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Slideshare', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_slideshare]" value="<?php echo esc_url( $options[ 'social_slideshare' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Instagram', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_instagram]" value="<?php echo esc_url( $options[ 'social_instagram' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Skype', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_skype]" value="<?php echo esc_attr( $options[ 'social_skype' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Soundcloud', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_soundcloud]" value="<?php echo esc_url( $options[ 'social_soundcloud' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Email', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_email]" value="<?php echo sanitize_email( $options[ 'social_email' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Xing', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_xing]" value="<?php echo esc_url( $options[ 'social_xing' ] ); ?>" />
                                    </td>
                                </tr>
                                <tr>
                                    <th scope="row"><?php _e( 'Enable SpecificFeeds?', 'catch-box' ); ?></th>
                                    <input type='hidden' value='0' name='catchbox_options[enable_specificfeeds]'>
                                    <td><input type="checkbox" id="headerlogo" name="catchbox_options[enable_specificfeeds]" value="1" <?php checked( '1', $options['enable_specificfeeds'] ); ?> /> <?php _e('Check to enable', 'catch-box'); ?></td>
                                </tr>
                                <tr>
                                    <th scope="row"><h4><?php _e( 'Meetup', 'catch-box' ); ?></h4></th>
                                    <td><input type="text" size="45" name="catchbox_options[social_meetup]" value="<?php echo esc_url( $options[ 'social_meetup' ] ); ?>" />
                                    </td>
                                </tr>
                            </tbody>
                        </table>
                        <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                    </div><!-- .option-container -->
                </div><!-- #sociallinks -->

              	<div id="webmaster">
                	<div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Site Verification', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><label><?php _e( 'Google Site Verification ID', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[google_verification]" value="<?php echo esc_attr( $options[ 'google_verification' ] ); ?>" /> <?php _e('Enter your Google ID number only', 'catch-box'); ?>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><label><?php _e( 'Yahoo Site Verification ID', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[yahoo_verification]" value="<?php echo esc_attr( $options[ 'yahoo_verification'] ); ?>" /> <?php _e('Enter your Yahoo ID number only', 'catch-box'); ?>
                                        </td>
                                    </tr>

                                    <tr>
                                        <th scope="row"><label><?php _e( 'Bing Site Verification ID', 'catch-box' ); ?></label></th>
                                        <td><input type="text" size="45" name="catchbox_options[bing_verification]" value="<?php echo esc_attr( $options[ 'bing_verification' ] ); ?>" /> <?php _e('Enter your Bing ID number only', 'catch-box'); ?>
                                        </td>
                                    </tr>
                                </tbody>
                            </table>
                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->

                    <div class="option-container">
                        <h3 class="option-toggle"><a href="#"><?php _e( 'Header and Footer Codes', 'catch-box' ); ?></a></h3>
                        <div class="option-content inside">
                            <table class="form-table">
                                <tbody>
                                    <tr>
                                        <th scope="row"><?php _e( 'Code to display on Header', 'catch-box' ); ?></th>
                                        <td>
                                        <textarea name="catchbox_options[analytic_header]" id="analytics" rows="7" cols="80" ><?php echo esc_html( $options[ 'analytic_header' ] ); ?></textarea>
                                        </td>
                                    </tr>
                                    <tr>
                                        <td></td><td><?php _e('Note: Here you can put scripts from Google, Facebook etc. which will load on Header', 'catch-box' ); ?></td>
                                    </tr>
                                    <tr>
                                        <th scope="row"><?php _e('Code to display on Footer', 'catch-box' ); ?></th>
                                        <td>
                                         <textarea name="catchbox_options[analytic_footer]" id="analytics" rows="7" cols="80" ><?php echo esc_html( $options[ 'analytic_footer' ] ); ?></textarea>

                                        </td>
                                    </tr>
                                    <tr>
                                        <td></td><td><?php _e( 'Note: Here you can put scripts from Google, Facebook, Add This etc. which will load on footer', 'catch-box' ); ?></td>
                                    </tr>
                                </tbody>
                            </table>

                            <p class="submit"><input type="submit" class="button-primary" value="<?php esc_attr_e( 'Save', 'catch-box' ); ?>" /></p>
                        </div><!-- .option-content -->
                    </div><!-- .option-container -->
                </div><!-- #webmaster -->

            </div><!-- #catchbox_ad_tabs -->
		</form>
	</div><!-- .wrap -->
<?php
}


/**
 * Validate content options
 * @param array $options
 * @uses esc_url_raw, absint, esc_textarea, sanitize_text_field, catchbox_invalidate_caches
 * @return array
 */
function catchbox_theme_options_validate( $options ) {
	global $catchbox_options_settings;
    $input_validated = $catchbox_options_settings;

	global $catchbox_options_defaults;
	$defaults = $catchbox_options_defaults;

	$fonts = catchbox_available_fonts();
	$units = array( 'px', 'pt', 'em', '%' );

    $input = array();
    $input = $options;

	// data validation for responsive layout
	if ( isset( $input['disable_responsive'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_responsive' ] = $input[ 'disable_responsive' ];
	}

	// data validation for scroll up
	if ( isset( $input['disable_scrollup'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_scrollup' ] = $input[ 'disable_scrollup' ];
	}

	// data validation for update notifier
	if ( isset( $input['disable_notifier'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_notifier' ] = $input[ 'disable_notifier' ];
	}

	if ( isset( $input['enable_menus'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'enable_menus' ] = $input[ 'enable_menus' ];
	}

	// data validation for favicon
	if ( isset( $input[ 'fav_icon' ] ) ) {
		$input_validated[ 'fav_icon' ] = esc_url_raw( $input[ 'fav_icon' ] );
	}

	if ( isset( $input['remove_favicon'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'remove_favicon' ] = $input[ 'remove_favicon' ];
	}

	// data validation for web clip icon
	if ( isset( $input[ 'web_clip' ] ) ) {
		$input_validated[ 'web_clip' ] = esc_url_raw( $input[ 'web_clip' ] );
	}
	if ( isset( $input['remove_web_clip'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'remove_web_clip' ] = $input[ 'remove_web_clip' ];
	}

	// fata validation for site tile above logo
	if ( isset( $input['site_title_above'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'site_title_above' ] = $input[ 'site_title_above' ];
	}

	// data validation for Search Settings
	if ( isset( $input[ 'search_display_text' ] ) ) {
        $input_validated[ 'search_display_text' ] = ( sanitize_text_field( $input[ 'search_display_text' ] ) ? $input['search_display_text'] : $defaults[ 'search_display_text' ] );
    }
	if ( isset( $input['disable_header_search'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_header_search' ] = $input[ 'disable_header_search' ];
	}

	if( isset( $input[ 'reset_header_space'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_header_space' ] = $input[ 'reset_header_space' ];
		$input_validated['header_top_size'] = number_format( floatval( $input['header_top_size'] ), 2, '.', '' );
		$input_validated['header_top_size_unit'] = ( in_array( $input['header_top_size_unit'], $units ) ? $input['header_top_size_unit'] : $defaults[ 'header_top_size_unit' ] );
		$input_validated['header_right_size'] = number_format( floatval( $input['header_right_size'] ), 2, '.', '' );
		$input_validated['header_right_size_unit'] = ( in_array( $input['header_right_size_unit'], $units ) ? $input['header_right_size_unit'] : $defaults[ 'header_right_size_unit' ] );
		$input_validated['header_bottom_size'] = number_format( floatval( $input['header_bottom_size'] ), 2, '.', '' );
		$input_validated['header_bottom_size_unit'] = ( in_array( $input['header_bottom_size_unit'], $units ) ? $input['header_bottom_size_unit'] : $defaults[ 'header_bottom_size_unit' ] );
		$input_validated['header_left_size'] = number_format( floatval( $input['header_left_size'] ), 2, '.', '' );
		$input_validated['header_left_size_unit'] = ( in_array( $input['header_left_size_unit'], $units ) ? $input['header_left_size_unit'] : $defaults[ 'header_left_size_unit' ] );
		if( $input[ 'reset_header_space'] == '1' )	{
			$input_validated['header_top_size'] = $defaults[ 'header_top_size' ];
			$input_validated['header_top_size_unit'] = $defaults[ 'header_top_size_unit' ];
			$input_validated['header_right_size'] = $defaults[ 'header_right_size' ];
			$input_validated['header_right_size_unit'] = $defaults[ 'header_right_size_unit' ];
			$input_validated['header_bottom_size'] = $defaults[ 'header_bottom_size' ];
			$input_validated['header_bottom_size_unit'] = $defaults[ 'header_bottom_size_unit' ];
			$input_validated['header_left_size'] = $defaults[ 'header_left_size' ];
			$input_validated['header_left_size_unit'] = $defaults[ 'header_left_size_unit' ];
		}
	}

    // data validation for Mobile Menu
    if( isset( $input[ 'primary_mobile_menu_label' ] ) ) {
        $input_validated[ 'primary_mobile_menu_label' ] = sanitize_text_field( $input[ 'primary_mobile_menu_label' ] );
    }
    if( isset( $input[ 'secondary_mobile_menu_label' ] ) ) {
        $input_validated[ 'secondary_mobile_menu_label' ] = sanitize_text_field( $input[ 'secondary_mobile_menu_label' ] );
    }
    if( isset( $input[ 'footer_mobile_menu_label' ] ) ) {
        $input_validated[ 'footer_mobile_menu_label' ] = sanitize_text_field( $input[ 'footer_mobile_menu_label' ] );
    }
    if ( isset( $input['hide_mobile_menu_labels'] ) ) {
        // Our checkbox value is either 0 or 1
        $input_validated[ 'hide_mobile_menu_labels' ] = $input[ 'hide_mobile_menu_labels' ];
    }

	// data validation for Color Scheme
	if ( isset( $input['color_scheme'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'color_scheme' ] = $input[ 'color_scheme' ];
	}
	if ( isset( $input[ 'header_background' ] ) ) {
		$input_validated[ 'header_background' ] = wp_filter_nohtml_kses( $input[ 'header_background' ] );
	}
	if ( isset( $input[ 'slider_background' ] ) ) {
		$input_validated[ 'slider_background' ] = wp_filter_nohtml_kses( $input[ 'slider_background' ] );
	}
	if ( isset( $input[ 'content_background' ] ) ) {
		$input_validated[ 'content_background' ] = wp_filter_nohtml_kses( $input[ 'content_background' ] );
	}
	if ( isset( $input[ 'article_background' ] ) ) {
		$input_validated[ 'article_background' ] = wp_filter_nohtml_kses( $input[ 'article_background' ] );
	}
	if ( isset( $input[ 'footer_background' ] ) ) {
		$input_validated[ 'footer_background' ] = wp_filter_nohtml_kses( $input[ 'footer_background' ] );
	}
	if ( isset( $input[ 'footer_sidebar_background' ] ) ) {
		$input_validated[ 'footer_sidebar_background' ] = wp_filter_nohtml_kses( $input[ 'footer_sidebar_background' ] );
	}
	if ( isset( $input[ 'content_background' ] ) ) {
		$input_validated[ 'content_background' ] = wp_filter_nohtml_kses( $input[ 'content_background' ] );
	}
	if ( isset( $input[ 'title_hover_color' ] ) ) {
		$input_validated[ 'title_hover_color' ] = wp_filter_nohtml_kses( $input[ 'title_hover_color' ] );
	}
	if ( isset( $input[ 'heading_color' ] ) ) {
		$input_validated[ 'heading_color' ] = wp_filter_nohtml_kses( $input[ 'heading_color' ] );
	}
	if ( isset( $input[ 'heading_hover_color' ] ) ) {
		$input_validated[ 'heading_hover_color' ] = wp_filter_nohtml_kses( $input[ 'heading_hover_color' ] );
	}
	if ( isset( $input[ 'slider_text' ] ) ) {
		$input_validated[ 'slider_text' ] = wp_filter_nohtml_kses( $input[ 'slider_text' ] );
	}
	if ( isset( $input[ 'meta_color' ] ) ) {
		$input_validated[ 'meta_color' ] = wp_filter_nohtml_kses( $input[ 'meta_color' ] );
	}
	if ( isset( $input[ 'text_color' ] ) ) {
		$input_validated[ 'text_color' ] = wp_filter_nohtml_kses( $input[ 'text_color' ] );
	}
	if ( isset( $input[ 'link_color' ] ) ) {
		$input_validated[ 'link_color' ] = wp_filter_nohtml_kses( $input[ 'link_color' ] );
	}
	if ( isset( $input[ 'widget_heading_color' ] ) ) {
		$input_validated[ 'widget_heading_color' ] = wp_filter_nohtml_kses( $input[ 'widget_heading_color' ] );
	}
	if ( isset( $input[ 'widget_text_color' ] ) ) {
		$input_validated[ 'widget_text_color' ] = wp_filter_nohtml_kses( $input[ 'widget_text_color' ] );
	}
	if ( isset( $input[ 'widget_background' ] ) ) {
		$input_validated[ 'widget_background' ] = wp_filter_nohtml_kses( $input[ 'widget_background' ] );
	}
	if ( isset( $input[ 'menu_background' ] ) ) {
		$input_validated[ 'menu_background' ] = wp_filter_nohtml_kses( $input[ 'menu_background' ] );
	}
	if ( isset( $input[ 'menu_color' ] ) ) {
		$input_validated[ 'menu_color' ] = wp_filter_nohtml_kses( $input[ 'menu_color' ] );
	}
	if ( isset( $input[ 'hover_background_color' ] ) ) {
		$input_validated[ 'hover_background_color' ] = wp_filter_nohtml_kses( $input[ 'hover_background_color' ] );
	}
	if ( isset( $input[ 'hover_text_color' ] ) ) {
		$input_validated[ 'hover_text_color' ] = wp_filter_nohtml_kses( $input[ 'hover_text_color' ] );
	}
	if ( isset( $input[ 'active_background_color' ] ) ) {
		$input_validated[ 'active_background_color' ] = wp_filter_nohtml_kses( $input[ 'active_background_color' ] );
	}
	if ( isset( $input[ 'active_text_color' ] ) ) {
		$input_validated[ 'active_text_color' ] = wp_filter_nohtml_kses( $input[ 'active_text_color' ] );
	}
	if ( isset( $input[ 'sub_menu_bg_color' ] ) ) {
		$input_validated[ 'sub_menu_bg_color' ] = wp_filter_nohtml_kses( $input[ 'sub_menu_bg_color' ] );
	}
	if ( isset( $input[ 'sub_menu_text_color' ] ) ) {
		$input_validated[ 'sub_menu_text_color' ] = wp_filter_nohtml_kses( $input[ 'sub_menu_text_color' ] );
	}
	if ( isset( $input[ 'scrollup_bg_color' ] ) ) {
		$input_validated[ 'scrollup_bg_color' ] = wp_filter_nohtml_kses( $input[ 'scrollup_bg_color' ] );
	}
	if ( isset( $input[ 'scrollup_text_color' ] ) ) {
		$input_validated[ 'scrollup_text_color' ] = wp_filter_nohtml_kses( $input[ 'scrollup_text_color' ] );
	}

	//Reset Color Options
	if ( isset( $input['reset_color'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_color' ] = $input[ 'reset_color' ];

		if ( $input['reset_color'] == '1' ) {
			$input_validated[ 'color_scheme' ] = $defaults[ 'color_scheme' ];
			$input_validated[ 'header_background' ] = $defaults[ 'header_background' ];
			$input_validated[ 'slider_background' ] = $defaults[ 'slider_background' ];
			$input_validated[ 'content_background' ] = $defaults[ 'content_background' ];
			$input_validated[ 'article_background' ] = $defaults[ 'article_background' ];
			$input_validated[ 'footer_background' ] = $defaults[ 'footer_background' ];
			$input_validated[ 'footer_sidebar_background' ] = $defaults[ 'footer_sidebar_background' ];
			$input_validated[ 'widget_background' ] = $defaults[ 'widget_background' ];
			$input_validated[ 'title_hover_color' ] = $defaults[ 'title_hover_color' ];
			$input_validated[ 'heading_color' ] = $defaults[ 'heading_color' ];
			$input_validated[ 'heading_hover_color' ] = $defaults[ 'heading_hover_color' ];
			$input_validated[ 'slider_text' ] = $defaults[ 'slider_text' ];
			$input_validated[ 'meta_color' ] = $defaults[ 'meta_color' ];
			$input_validated[ 'text_color' ] = $defaults[ 'text_color' ];
			$input_validated[ 'link_color' ] = $defaults[ 'link_color' ];
			$input_validated[ 'widget_heading_color' ] = $defaults[ 'widget_heading_color' ];
			$input_validated[ 'widget_text_color' ] = $defaults[ 'widget_text_color' ];
			$input_validated[ 'menu_background' ] = $defaults[ 'menu_background' ];
			$input_validated[ 'menu_color' ] = $defaults[ 'menu_color' ];
			$input_validated[ 'hover_background_color' ] = $defaults[ 'hover_background_color' ];
			$input_validated[ 'hover_text_color' ] = $defaults[ 'hover_text_color' ];
			$input_validated[ 'active_background_color' ] = $defaults[ 'active_background_color' ];
			$input_validated[ 'active_text_color' ] = $defaults[ 'active_text_color' ];
			$input_validated[ 'sub_menu_bg_color' ] = $defaults[ 'sub_menu_bg_color' ];
			$input_validated[ 'sub_menu_text_color' ] = $defaults[ 'sub_menu_text_color' ];
			$input_validated[ 'scrollup_bg_color' ] = $defaults[ 'scrollup_bg_color' ];
			$input_validated[ 'scrollup_text_color' ] = $defaults[ 'scrollup_text_color' ];

		}
	}


	// data validation for Font Family Options
	if( isset( $input[ 'reset_typography'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_typography' ] = $input[ 'reset_typography' ];
		$input_validated['body_font'] = ( array_key_exists( $input['body_font'], $fonts ) ? $input['body_font'] : $defaults[ 'body_font' ] );
		$input_validated['title_font'] = ( array_key_exists( $input['title_font'], $fonts ) ? $input['title_font'] : $defaults[ 'title_font' ] );
		$input_validated['headings_font'] = ( array_key_exists( $input['headings_font'], $fonts ) ? $input['headings_font'] : $defaults[ 'headings_font' ] );
		$input_validated['content_font'] = ( array_key_exists( $input['content_font'], $fonts ) ? $input['content_font'] : $defaults[ 'content_font' ] );

		if( $input[ 'reset_typography'] == '1' ) {
			$input_validated['body_font'] = $defaults[ 'body_font' ];
			$input_validated['title_font'] = $defaults[ 'title_font' ];
			$input_validated['headings_font'] = $defaults[ 'headings_font' ];
			$input_validated['content_font'] = $defaults[ 'content_font' ];
		}
	}



	// data validation for Font Size Options
	if( isset( $input[ 'reset_typography_font_size'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_typography_font_size' ] = $input[ 'reset_typography_font_size' ];

		$input_validated['body_font_size'] = number_format( floatval( $input['body_font_size'] ), 2, '.', '' );
		$input_validated['body_font_size_unit'] = ( in_array( $input['body_font_size_unit'], $units ) ? $input['body_font_size_unit'] : $defaults[ 'body_font_size_unit' ] );

		$input_validated['body_line_height'] = number_format( floatval( $input['body_line_height'] ), 2, '.', '' );
		$input_validated['body_line_height_unit'] = ( in_array( $input['body_line_height_unit'], $units ) ? $input['body_line_height_unit'] : $defaults[ 'body_line_height_unit' ] );

		$input_validated['site_title_font_size'] = number_format( floatval( $input['site_title_font_size'] ), 2, '.', '' );
		$input_validated['site_title_font_size_unit'] = ( in_array( $input['site_title_font_size_unit'], $units ) ? $input['site_title_font_size_unit'] : $defaults[ 'site_title_font_size_unit' ] );

		$input_validated['site_title_line_height'] = number_format( floatval( $input['site_title_line_height'] ), 2, '.', '' );
		$input_validated['site_title_line_height_unit'] = ( in_array( $input['site_title_line_height_unit'], $units ) ? $input['site_title_line_height_unit'] : $defaults[ 'site_title_line_height_unit' ] );

		$input_validated['site_description_font_size'] = number_format( floatval( $input['site_description_font_size'] ), 2, '.', '' );
		$input_validated['site_description_font_size_unit'] = ( in_array( $input['site_description_font_size_unit'], $units ) ? $input['site_description_font_size_unit'] : $defaults[ 'site_description_font_size_unit' ] );

		$input_validated['site_description_line_height'] = number_format( floatval( $input['site_description_line_height'] ), 2, '.', '' );
		$input_validated['site_description_line_height_unit'] = ( in_array( $input['site_description_line_height_unit'], $units ) ? $input['site_description_line_height_unit'] : $defaults[ 'site_description_line_height_unit' ] );

        $input_validated['title_font_size'] = number_format( floatval( $input['title_font_size'] ), 2, '.', '' );
        $input_validated['title_font_size_unit'] = ( in_array( $input['title_font_size_unit'], $units ) ? $input['title_font_size_unit'] : $defaults[ 'title_font_size_unit' ] );

		$input_validated['h1_font_size'] = number_format( floatval( $input['h1_font_size'] ), 2, '.', '' );
		$input_validated['h1_font_size_unit'] = ( in_array( $input['h1_font_size_unit'], $units ) ? $input['h1_font_size_unit'] : $defaults[ 'h1_font_size_unit' ] );

		$input_validated['h2_font_size'] = number_format( floatval( $input['h2_font_size'] ), 2, '.', '' );
		$input_validated['h2_font_size_unit'] = ( in_array( $input['h2_font_size_unit'], $units ) ? $input['h2_font_size_unit'] : $defaults[ 'h2_font_size_unit' ] );

		$input_validated['h3_font_size'] = number_format( floatval( $input['h3_font_size'] ), 2, '.', '' );
		$input_validated['h3_font_size_unit'] = ( in_array( $input['h3_font_size_unit'], $units ) ? $input['h3_font_size_unit'] : $defaults[ 'h3_font_size_unit' ] );

		$input_validated['h4_font_size'] = number_format( floatval( $input['h4_font_size'] ), 2, '.', '' );
		$input_validated['h4_font_size_unit'] = ( in_array( $input['h4_font_size_unit'], $units ) ? $input['h4_font_size_unit'] : $defaults[ 'h4_font_size_unit' ] );

		$input_validated['headings_line_height'] = number_format( floatval( $input['headings_line_height'] ), 2, '.', '' );
		$input_validated['headings_line_height_unit'] = ( in_array( $input['headings_line_height_unit'], $units ) ? $input['headings_line_height_unit'] : $defaults[ 'headings_line_height_unit' ] );

		$input_validated['content_font_size'] = number_format( floatval( $input['content_font_size'] ), 2, '.', '' );
		$input_validated['content_font_size_unit'] = ( in_array( $input['content_font_size_unit'], $units ) ? $input['content_font_size_unit'] : $defaults[ 'content_font_size_unit' ] );

		$input_validated['content_line_height'] =  number_format( floatval( $input['content_line_height'] ), 2, '.', '' );
		$input_validated['content_line_height_unit'] = ( in_array( $input['content_line_height_unit'], $units ) ? $input['content_line_height_unit'] : $defaults[ 'content_line_height_unit' ] );

		if( $input[ 'reset_typography_font_size'] == '1' )	{
			$input_validated['body_font_size'] = $defaults[ 'body_font_size' ];
			$input_validated['body_font_size_unit'] = $defaults[ 'body_font_size_unit' ];
			$input_validated['body_line_height'] = $defaults[ 'body_line_height' ];
			$input_validated['body_line_height_unit'] = $defaults[ 'body_line_height_unit' ];
			$input_validated['site_title_font_size'] = $defaults[ 'site_title_font_size' ];
			$input_validated['site_title_font_size_unit'] = $defaults[ 'site_title_font_size_unit' ];
			$input_validated['site_title_line_height'] = $defaults[ 'site_title_line_height' ];
			$input_validated['site_title_line_height_unit'] = $defaults[ 'site_title_line_height_unit' ];
			$input_validated['site_description_font_size'] = $defaults[ 'site_description_font_size' ];
			$input_validated['site_description_font_size_unit'] = $defaults[ 'site_description_font_size_unit' ];
			$input_validated['site_description_line_height'] = $defaults[ 'site_description_line_height' ];
			$input_validated['site_description_line_height_unit'] = $defaults[ 'site_description_line_height_unit' ];
			$input_validated['h1_font_size'] = $defaults[ 'h1_font_size' ];
			$input_validated['h1_font_size_unit'] = $defaults[ 'h1_font_size_unit' ];
			$input_validated['h2_font_size'] = $defaults[ 'h2_font_size' ];
			$input_validated['h2_font_size_unit'] = $defaults[ 'h2_font_size_unit' ];
			$input_validated['h3_font_size'] = $defaults[ 'h3_font_size' ];
			$input_validated['h3_font_size_unit'] = $defaults[ 'h3_font_size_unit' ];
			$input_validated['h4_font_size'] = $defaults[ 'h4_font_size' ];
			$input_validated['h4_font_size_unit'] = $defaults[ 'h4_font_size_unit' ];
			$input_validated['headings_line_height'] = $defaults[ 'headings_line_height' ];
			$input_validated['headings_line_height_unit'] = $defaults[ 'headings_line_height_unit' ];
			$input_validated['content_font_size'] = $defaults[ 'content_font_size' ];
			$input_validated['content_font_size_unit'] = $defaults[ 'content_font_size_unit' ];
			$input_validated['content_line_height'] = $defaults[ 'content_line_height' ];
			$input_validated['content_line_height_unit'] = $defaults[ 'content_line_height_unit' ];
		}
	}

    // data validation for Default Layout verification
	if ( isset( $input[ 'sidebar_layout' ] ) ) {
		$input_validated[ 'sidebar_layout' ] = $input[ 'sidebar_layout' ];
	}
	if ( isset( $input['reset_sidebar_layout'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_sidebar_layout' ] = $input[ 'reset_sidebar_layout' ];

		if ( $input['reset_sidebar_layout'] == 1 ) {
			$input_validated[ 'sidebar_layout' ] = $defaults[ 'sidebar_layout' ];
		}
	}


    // data validation for Homepage Content Layout verification
	if ( isset( $input[ 'content_layout' ] ) ) {
		$input_validated[ 'content_layout' ] = $input[ 'content_layout' ];
	}

	// data validation for Custom CSS Style
	if ( isset( $input['custom_css'] ) ) {
		$input_validated['custom_css'] = wp_kses_stripslashes($input['custom_css']);
	}

	// data validation for Homepage/Frontpage posts categories
    if ( isset( $input['front_page_category' ] ) ) {
		$input_validated['front_page_category'] = $input['front_page_category'];
    }

    // data validation for enable More Tags accessible
    if ( isset( $input[ 'more_tag_accessible' ] ) ) {
        $input_validated[ 'more_tag_accessible' ] = sanitize_text_field ( $input[ 'more_tag_accessible' ] );
    }
    // data validation for More Tags accessible
    if ( isset( $input[ 'more_tag_text_accessible' ] ) ) {
        $input_validated[ 'more_tag_text_accessible' ] = sanitize_text_field ( $input[ 'more_tag_text_accessible' ] );
    }
    // data validation for More Tags icon
    if ( isset( $input[ 'more_tag_icon_accessible' ] ) ) {
        $input_validated[ 'more_tag_icon_accessible' ] = sanitize_text_field ( $input[ 'more_tag_icon_accessible' ] );
    }

	// data validation for More Tags and Excerpt Length
    if ( isset( $input[ 'more_tag_text' ] ) ) {
        $input_validated[ 'more_tag_text' ] = sanitize_text_field ( $input[ 'more_tag_text' ] );
    }
    //data validation for excerpt length
    if ( isset( $input[ 'excerpt_length' ] ) ) {
        $input_validated[ 'excerpt_length' ] = absint( $input[ 'excerpt_length' ] ) ? $input [ 'excerpt_length' ] : 30;
    }

	//Feed Redirect
	if ( isset( $input[ 'feed_url' ] ) ) {
		$input_validated['feed_url'] = esc_url_raw($input['feed_url']);
	}

	// Data Validation for Comment Setting
	if ( isset( $input[ 'commenting_setting' ] ) ) {
		$input_validated[ 'commenting_setting' ] = $input[ 'commenting_setting' ];
	}
	if ( isset( $input['commenting_disable_url'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'commenting_disable_url' ] = $input[ 'commenting_disable_url' ];
	}

	//footer text
	if( isset( $input[ 'footer_code' ] ) ) {
		$input_validated['footer_code'] =  stripslashes( wp_filter_post_kses( addslashes ( $input['footer_code'] ) ) );
	}
	if ( isset( $input['reset_footer'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'reset_footer' ] = $input[ 'reset_footer' ];
	}

	//Reset Footer
	if ( $input[ 'reset_footer' ] == 1 ) {
		$input_validated[ 'footer_code' ] = $defaults[ 'footer_code' ];
	}


    if ( isset( $input['exclude_slider_post'] ) ) {
        // Our checkbox value is either 0 or 1
   		$input_validated[ 'exclude_slider_post' ] = $input[ 'exclude_slider_post' ];

    }

	// data validation Slider Options

	// data validation for Slider Type
	if( isset( $input[ 'select_slider_type' ] ) ) {
		$input_validated[ 'select_slider_type' ] = $input[ 'select_slider_type' ];
	}
	if( isset( $input[ 'select_slider_layout' ] ) ) {
		$input_validated[ 'select_slider_layout' ] = $input[ 'select_slider_layout' ];
	}
	// data validation for Enable Slider
	if( isset( $input[ 'enable_slider' ] ) ) {
		$input_validated[ 'enable_slider' ] = $input[ 'enable_slider' ];
	}
    // data validation for number of slides
	if ( isset( $input[ 'slider_qty' ] ) ) {
		$input_validated[ 'slider_qty' ] = absint( $input[ 'slider_qty' ] ) ? $input [ 'slider_qty' ] : 4;
	}
    // data validation for transition effect
    if( isset( $input[ 'transition_effect' ] ) ) {
        $input_validated['transition_effect'] = wp_filter_nohtml_kses( $input['transition_effect'] );
    }
    // data validation for transition delay
    if ( isset( $input[ 'transition_delay' ] ) && is_numeric( $input[ 'transition_delay' ] ) ) {
        $input_validated[ 'transition_delay' ] = $input[ 'transition_delay' ];
    }
    // data validation for transition length
    if ( isset( $input[ 'transition_duration' ] ) && is_numeric( $input[ 'transition_duration' ] ) ) {
        $input_validated[ 'transition_duration' ] = $input[ 'transition_duration' ];
    }

	// data validation for Featured Post and Page Slider
	if ( isset( $input[ 'featured_slider' ] ) ) {
		$input_validated[ 'featured_slider' ] = array();
	}
	if ( isset( $input[ 'featured_slider_page' ] ) ) {
		$input_validated[ 'featured_slider_page' ] = array();
	}
 	if ( isset( $input[ 'slider_qty' ] ) )	{
		for ( $i = 1; $i <= $input [ 'slider_qty' ]; $i++ ) {
			if ( !empty( $input[ 'featured_slider' ][ $i ] ) && intval( $input[ 'featured_slider' ][ $i ] ) ) {
				$input_validated[ 'featured_slider' ][ $i ] = absint($input[ 'featured_slider' ][ $i ] );
			}
			if ( !empty( $input[ 'featured_slider_page' ][ $i ] ) && intval( $input[ 'featured_slider_page' ][ $i ] ) ) {
				$input_validated[ 'featured_slider_page' ][ $i ] = absint($input[ 'featured_slider_page' ][ $i ] );
			}
		}
	}

	// data validation for Featured Image Slider
	if ( isset( $input[ 'featured_image_slider_image' ] ) ) {
		$input_validated[ 'featured_image_slider_image' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_link' ] ) ) {
		$input_validated[ 'featured_image_slider_link' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_base' ] ) ) {
		$input_validated[ 'featured_image_slider_base' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_title' ] ) ) {
		$input_validated[ 'featured_image_slider_title' ] = array();
	}
	if ( isset( $input[ 'featured_image_slider_content' ] ) ) {
		$input_validated[ 'featured_image_slider_content' ] = array();
	}
 	if ( isset( $input[ 'slider_qty' ] ) )	{
		for ( $i = 1; $i <= $input [ 'slider_qty' ]; $i++ ) {
			if ( !empty( $input[ 'featured_image_slider_image' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_image' ][ $i ] = esc_url_raw($input[ 'featured_image_slider_image' ][ $i ] );
			}
			if ( !empty( $input[ 'featured_image_slider_link' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_link'][ $i ] = esc_url_raw($input[ 'featured_image_slider_link'][ $i ]);
			}
			if ( !empty( $input[ 'featured_image_slider_base' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_base'][ $i ] = $input[ 'featured_image_slider_base'][ $i ];
			}
			if ( !empty( $input[ 'featured_image_slider_title' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_title'][ $i ] = sanitize_text_field($input[ 'featured_image_slider_title'][ $i ]);
			}
			if ( !empty( $input[ 'featured_image_slider_content' ][ $i ] ) ) {
				$input_validated[ 'featured_image_slider_content'][ $i ] = wp_kses_stripslashes($input[ 'featured_image_slider_content'][ $i ]);
			}
		}
	}
	//Featured Catgory Slider
	if ( isset( $input['slider_category'] ) ) {
		$input_validated[ 'slider_category' ] = $input[ 'slider_category' ];
	}

	// data validation for Social Icons
	if ( isset( $input['disable_footer_social'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'disable_footer_social' ] = $input[ 'disable_footer_social' ];
	}
	if( isset( $input[ 'social_facebook' ] ) ) {
		$input_validated[ 'social_facebook' ] = esc_url_raw( $input[ 'social_facebook' ] );
	}
	if( isset( $input[ 'social_twitter' ] ) ) {
		$input_validated[ 'social_twitter' ] = esc_url_raw( $input[ 'social_twitter' ] );
	}
	if( isset( $input[ 'social_googleplus' ] ) ) {
		$input_validated[ 'social_googleplus' ] = esc_url_raw( $input[ 'social_googleplus' ] );
	}
	if( isset( $input[ 'social_pinterest' ] ) ) {
		$input_validated[ 'social_pinterest' ] = esc_url_raw( $input[ 'social_pinterest' ] );
	}
	if( isset( $input[ 'social_youtube' ] ) ) {
		$input_validated[ 'social_youtube' ] = esc_url_raw( $input[ 'social_youtube' ] );
	}
	if( isset( $input[ 'social_vimeo' ] ) ) {
		$input_validated[ 'social_vimeo' ] = esc_url_raw( $input[ 'social_vimeo' ] );
	}
	if( isset( $input[ 'social_linkedin' ] ) ) {
		$input_validated[ 'social_linkedin' ] = esc_url_raw( $input[ 'social_linkedin' ] );
	}
	if( isset( $input[ 'social_aim' ] ) ) {
		$input_validated[ 'social_aim' ] = esc_url_raw( $input[ 'social_aim' ] );
	}
	if( isset( $input[ 'social_myspace' ] ) ) {
		$input_validated[ 'social_myspace' ] = esc_url_raw( $input[ 'social_myspace' ] );
	}
	if( isset( $input[ 'social_flickr' ] ) ) {
		$input_validated[ 'social_flickr' ] = esc_url_raw( $input[ 'social_flickr' ] );
	}
	if( isset( $input[ 'social_tumblr' ] ) ) {
		$input_validated[ 'social_tumblr' ] = esc_url_raw( $input[ 'social_tumblr' ] );
	}
	if( isset( $input[ 'social_deviantart' ] ) ) {
		$input_validated[ 'social_deviantart' ] = esc_url_raw( $input[ 'social_deviantart' ] );
	}
	if( isset( $input[ 'social_dribbble' ] ) ) {
		$input_validated[ 'social_dribbble' ] = esc_url_raw( $input[ 'social_dribbble' ] );
	}
	if( isset( $input[ 'social_wordpress' ] ) ) {
		$input_validated[ 'social_wordpress' ] = esc_url_raw( $input[ 'social_wordpress' ] );
	}
	if( isset( $input[ 'social_rss' ] ) ) {
		$input_validated[ 'social_rss' ] = esc_url_raw( $input[ 'social_rss' ] );
	}
	if( isset( $input[ 'social_slideshare' ] ) ) {
		$input_validated[ 'social_slideshare' ] = esc_url_raw( $input[ 'social_slideshare' ] );
	}
	if( isset( $input[ 'social_instagram' ] ) ) {
		$input_validated[ 'social_instagram' ] = esc_url_raw( $input[ 'social_instagram' ] );
	}
	if( isset( $input[ 'social_skype' ] ) ) {
		$input_validated[ 'social_skype' ] = sanitize_text_field( $input[ 'social_skype' ] );
	}
	if( isset( $input[ 'social_soundcloud' ] ) ) {
		$input_validated[ 'social_soundcloud' ] = esc_url_raw( $input[ 'social_soundcloud' ] );
	}
	if( isset( $input[ 'social_email' ] ) &&  isset( $input[ 'social_email' ] )  ) {
		$input_validated[ 'social_email' ] = sanitize_email( $input[ 'social_email' ] );
	}
	if( isset( $input[ 'social_xing' ] ) ) {
		$input_validated[ 'social_xing' ] = esc_url_raw( $input[ 'social_xing' ] );
	}
	if ( isset( $input['enable_specificfeeds'] ) ) {
		// Our checkbox value is either 0 or 1
		$input_validated[ 'enable_specificfeeds' ] = $input[ 'enable_specificfeeds' ];
	}
    if( isset( $input[ 'social_meetup' ] ) ) {
        $input_validated[ 'social_meetup' ] = esc_url_raw( $input[ 'social_meetup' ] );
    }

	//Webmaster Tool Verification
	if( isset( $input[ 'google_verification' ] ) ) {
		$input_validated[ 'google_verification' ] = wp_filter_post_kses( $input[ 'google_verification' ] );
	}
	if( isset( $input[ 'yahoo_verification' ] ) ) {
		$input_validated[ 'yahoo_verification' ] = wp_filter_post_kses( $input[ 'yahoo_verification' ] );
	}
	if( isset( $input[ 'bing_verification' ] ) ) {
		$input_validated[ 'bing_verification' ] = wp_filter_post_kses( $input[ 'bing_verification' ] );
	}
	if( isset( $input[ 'analytic_header' ] ) ) {
		$input_validated[ 'analytic_header' ] = wp_kses_stripslashes( $input[ 'analytic_header' ] );
	}
	if( isset( $input[ 'analytic_footer' ] ) ) {
		$input_validated[ 'analytic_footer' ] = wp_kses_stripslashes( $input[ 'analytic_footer' ] );
	}

	//Clearing the theme option cache
	if( function_exists( 'catchbox_themeoption_invalidate_caches' ) ) catchbox_themeoption_invalidate_caches();

	return $input_validated;
}


/*
 * Clearing the cache if any changes in Admin Theme Option
 */
function catchbox_themeoption_invalidate_caches(){
	delete_transient( 'catchbox_responsive' ); // Disable responsive layout
	delete_transient( 'catchbox_favicon' );	  // favicon on cpanel/ backend and frontend
	delete_transient( 'catchbox_web_clip' ); // web clip icons
	delete_transient( 'catchbox_inline_css' ); // Custom Inline CSS and color options
	delete_transient( 'catchbox_sliders' ); // featured post slider
	delete_transient( 'catchbox_page_sliders' ); // featured page slider
	delete_transient( 'catchbox_category_sliders' ); // featured category slider
	delete_transient( 'catchbox_imagesliders' ); // featured image slider
	delete_transient( 'catchbox_social_networks' );  // Social links on header
	delete_transient( 'catchbox_site_verification' ); // scripts which loads on header
	delete_transient( 'catchbox_footercode' ); // scripts which loads on footer
	delete_transient( 'catchbox_footer_content' ); // Footer content
}

/*
 * Clearing the cache if any changes in post or page
 */
function catchbox_post_invalidate_caches(){
	delete_transient( 'catchbox_sliders' ); // featured post slider
	delete_transient( 'catchbox_page_sliders' ); // featured page slider
	delete_transient( 'catchbox_category_sliders' ); // featured category slider
}
//Add action hook here save post
add_action( 'save_post', 'catchbox_post_invalidate_caches' );


/**
 * Function to display the current year.
 *
 * @uses date() Gets the current year.
 * @return string
 */
function catchbox_the_year() {
	return date( __( 'Y', 'catch-box' ) );
}


/**
 * Function to display a link back to the site.
 *
 * @uses get_bloginfo() Gets the site link
 * @return string
 */
function catchbox_site_link() {
	return '<a href="' . esc_url( home_url( '/' ) ) . '" title="' . esc_attr( get_bloginfo( 'name', 'display' ) ) . '" ><span>' . get_bloginfo( 'name', 'display' ) . '</span></a>';
}


/**
 * Function to display a link to WordPress.org.
 *
 * @return string
 */
function catchbox_wp_link() {
	return '<a href="http://wordpress.org" target="_blank" title="' . esc_attr__( 'WordPress', 'catch-box' ) . '"><span>' . __( 'WordPress', 'catch-box' ) . '</span></a>';
}


/**
 * Function to display a link to Theme Link.
 *
 * @return string
 */
function catchbox_theme_link() {
	return '<a href="http://catchthemes.com/themes/catch-box-pro" target="_blank" title="' . esc_attr__( 'Catch Box Pro', 'catch-box' ) . '"><span>' . __( 'Catch Box Pro', 'catch-box' ) . '</span></a>';
}

/**
 * Returns the options array for Catch Box.
 *
 * @since Catch Box 4.4
 */
function catchbox_get_theme_options() {
    return get_option( 'catchbox_theme_options', catchbox_get_default_theme_options() );
}

/**
 * Returns the default options for Catch Box.
 *
 * @since Catch Box 4.4
 */
function catchbox_get_default_theme_options() {
    $default_theme_options = array(
        'excerpt_length'        => 40,
        'color_scheme'          => 'light',
        'link_color'            => catchbox_get_default_link_color( 'light' ),
        'theme_layout'          => 'content-sidebar',
        'content_layout'        => 'excerpt',
        'site_title_above'      => '0',
        'disable_header_search' => '0',
        'enable_menus'          => '0',
        'search_display_text'   => 'Search',

        //Feature Slider
        'exclude_slider_post'   => '0',
        'slider_qty'            => 4,
        'transition_effect'     => 'fade',
        'transition_delay'      => 4,
        'transition_duration'   => 1,
    );

    if ( is_rtl() )
        $default_theme_options['theme_layout'] = 'sidebar-content';

    return apply_filters( 'catchbox_default_theme_options', $default_theme_options );
}

/**
 * Returns the default link color for Catch Box, based on color scheme.
 *
 * @since Catch Box 1.0
 *
 * @param $string $color_scheme Color scheme. Defaults to the active color scheme.
 * @return $string Color.
*/
function catchbox_get_default_link_color( $color_scheme = null ) {
    if ( null === $color_scheme ) {
        $options = catchbox_get_theme_options();
        $color_scheme = $options['color_scheme'];
    }

    $color_schemes = catchbox_color_schemes();
    if ( ! isset( $color_schemes[ $color_scheme ] ) )
        return false;

    return $color_schemes[ $color_scheme ]['default_link_color'];
}

/**
 * Returns an array of color schemes registered for Catch Box.
 *
 * @since Catch Box 1.0
 */
function catchbox_color_schemes() {
    $color_scheme_options = array(
        'light'                     => array(
            'value'                 => 'light',
            'label'                 => __( 'Light', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/light.png',
            'default_link_color'    => '#1b8be0',
        ),
        'dark'                      => array(
            'value'                 => 'dark',
            'label'                 => __( 'Dark', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/dark.png',
            'default_link_color'    => '#e4741f',
        ),
        'blue'                      => array(
            'value'                 => 'blue',
            'label'                 => __( 'Blue', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/blue.png',
            'default_link_color'    => '#326693',
        ),
        'green'                         => array(
            'value'                 => 'green',
            'label'                 => __( 'Green', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/green.png',
            'default_link_color'    => '#3e6107',
        ),
        'red'                       => array(
            'value'                 => 'red',
            'label'                 => __( 'Red', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/red.png',
            'default_link_color'    => '#a6201d',
        ),
        'brown'                     => array(
            'value'                 => 'brown',
            'label'                 => __( 'Brown', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/brown.png',
            'default_link_color'    => '#5e3929',
        ),
        'orange'                    => array(
            'value'                 => 'orange',
            'label'                 => __( 'Orange', 'catch-box' ),
            'thumbnail'             => get_template_directory_uri() . '/inc/images/orange.png',
            'default_link_color'    => '#802602',
        )
    );

    return apply_filters( 'catchbox_color_schemes', $color_scheme_options );
}

/**
 * Returns an array of layout options registered for Catch Box.
 *
 * @since Catch Box 1.0
 */
function catchbox_layouts() {
    $layout_options = array(
        'right-sidebar' => __( 'Content on left', 'catch-box'),
        'left-sidebar' => __( 'Content on right', 'catch-box'),
        'no-sidebar-one-column' => __( 'One-column, no sidebar', 'catch-box'),
        'no-sidebar-full-width' => __( 'No sidebar full width', 'catch-box'),
        'no-sidebar' => __( 'No Sidebar', 'catch-box'),
    );

    return apply_filters( 'catchbox_layouts', $layout_options );
}

/**
 * Returns an array of content layout options registered for Catch Box.
 *
 * @since Catch Box 1.0
 */
function catchbox_content_layout() {
    $content_options = array(
        'excerpt'           => array(
            'value'         => 'excerpt',
            'label'         => __( 'Show excerpt', 'catch-box' ),
            'thumbnail'     => get_template_directory_uri() . '/inc/images/excerpt.png',
        ),
        'full-content'      => array(
            'value'         => 'full-content',
            'label'         => __( 'Show full content', 'catch-box' ),
            'thumbnail'     => get_template_directory_uri() . '/inc/images/full-content.png',
        )
    );

    return apply_filters( 'catchbox_content_layouts', $content_options );
}
